# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetFunctionsResult',
    'AwaitableGetFunctionsResult',
    'get_functions',
    'get_functions_output',
]

@pulumi.output_type
class GetFunctionsResult:
    """
    A collection of values returned by getFunctions.
    """
    def __init__(__self__, catalog_name=None, functions=None, id=None, include_browse=None, provider_config=None, schema_name=None):
        if catalog_name and not isinstance(catalog_name, str):
            raise TypeError("Expected argument 'catalog_name' to be a str")
        pulumi.set(__self__, "catalog_name", catalog_name)
        if functions and not isinstance(functions, list):
            raise TypeError("Expected argument 'functions' to be a list")
        pulumi.set(__self__, "functions", functions)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if include_browse and not isinstance(include_browse, bool):
            raise TypeError("Expected argument 'include_browse' to be a bool")
        pulumi.set(__self__, "include_browse", include_browse)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)
        if schema_name and not isinstance(schema_name, str):
            raise TypeError("Expected argument 'schema_name' to be a str")
        pulumi.set(__self__, "schema_name", schema_name)

    @_builtins.property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> _builtins.str:
        """
        Name of parent catalog.
        """
        return pulumi.get(self, "catalog_name")

    @_builtins.property
    @pulumi.getter
    def functions(self) -> Sequence['outputs.GetFunctionsFunctionResult']:
        """
        list of objects describing individual UDF. Each object consists of the following attributes (refer to [REST API documentation](https://docs.databricks.com/api/workspace/functions/list#functions) for up-to-date list of attributes. Default type is String):
        """
        return pulumi.get(self, "functions")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="includeBrowse")
    def include_browse(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "include_browse")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetFunctionsProviderConfigResult']:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> _builtins.str:
        """
        Name of parent schema relative to its parent catalog.
        """
        return pulumi.get(self, "schema_name")


class AwaitableGetFunctionsResult(GetFunctionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFunctionsResult(
            catalog_name=self.catalog_name,
            functions=self.functions,
            id=self.id,
            include_browse=self.include_browse,
            provider_config=self.provider_config,
            schema_name=self.schema_name)


def get_functions(catalog_name: Optional[_builtins.str] = None,
                  functions: Optional[Sequence[Union['GetFunctionsFunctionArgs', 'GetFunctionsFunctionArgsDict']]] = None,
                  include_browse: Optional[_builtins.bool] = None,
                  provider_config: Optional[Union['GetFunctionsProviderConfigArgs', 'GetFunctionsProviderConfigArgsDict']] = None,
                  schema_name: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFunctionsResult:
    """
    Retrieves a list of [User-Defined Functions (UDFs) registered in the Unity Catalog](https://docs.databricks.com/en/udf/unity-catalog.html).

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    List all functions defined in a specific schema (`main.default` in this example):

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_functions(catalog_name="main",
        schema_name="default")
    pulumi.export("allExternalLocations", all.functions)
    ```

    ## Related Resources

    The following resources are used in the same context:

    * Schema to get information about a single schema


    :param _builtins.str catalog_name: Name of databricks_catalog.
    :param Sequence[Union['GetFunctionsFunctionArgs', 'GetFunctionsFunctionArgsDict']] functions: list of objects describing individual UDF. Each object consists of the following attributes (refer to [REST API documentation](https://docs.databricks.com/api/workspace/functions/list#functions) for up-to-date list of attributes. Default type is String):
    :param _builtins.bool include_browse: flag to specify if include UDFs in the response for which the principal can only access selective metadata for.
    :param _builtins.str schema_name: Name of databricks_schema.
    """
    __args__ = dict()
    __args__['catalogName'] = catalog_name
    __args__['functions'] = functions
    __args__['includeBrowse'] = include_browse
    __args__['providerConfig'] = provider_config
    __args__['schemaName'] = schema_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getFunctions:getFunctions', __args__, opts=opts, typ=GetFunctionsResult).value

    return AwaitableGetFunctionsResult(
        catalog_name=pulumi.get(__ret__, 'catalog_name'),
        functions=pulumi.get(__ret__, 'functions'),
        id=pulumi.get(__ret__, 'id'),
        include_browse=pulumi.get(__ret__, 'include_browse'),
        provider_config=pulumi.get(__ret__, 'provider_config'),
        schema_name=pulumi.get(__ret__, 'schema_name'))
def get_functions_output(catalog_name: Optional[pulumi.Input[_builtins.str]] = None,
                         functions: Optional[pulumi.Input[Optional[Sequence[Union['GetFunctionsFunctionArgs', 'GetFunctionsFunctionArgsDict']]]]] = None,
                         include_browse: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                         provider_config: Optional[pulumi.Input[Optional[Union['GetFunctionsProviderConfigArgs', 'GetFunctionsProviderConfigArgsDict']]]] = None,
                         schema_name: Optional[pulumi.Input[_builtins.str]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFunctionsResult]:
    """
    Retrieves a list of [User-Defined Functions (UDFs) registered in the Unity Catalog](https://docs.databricks.com/en/udf/unity-catalog.html).

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    List all functions defined in a specific schema (`main.default` in this example):

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_functions(catalog_name="main",
        schema_name="default")
    pulumi.export("allExternalLocations", all.functions)
    ```

    ## Related Resources

    The following resources are used in the same context:

    * Schema to get information about a single schema


    :param _builtins.str catalog_name: Name of databricks_catalog.
    :param Sequence[Union['GetFunctionsFunctionArgs', 'GetFunctionsFunctionArgsDict']] functions: list of objects describing individual UDF. Each object consists of the following attributes (refer to [REST API documentation](https://docs.databricks.com/api/workspace/functions/list#functions) for up-to-date list of attributes. Default type is String):
    :param _builtins.bool include_browse: flag to specify if include UDFs in the response for which the principal can only access selective metadata for.
    :param _builtins.str schema_name: Name of databricks_schema.
    """
    __args__ = dict()
    __args__['catalogName'] = catalog_name
    __args__['functions'] = functions
    __args__['includeBrowse'] = include_browse
    __args__['providerConfig'] = provider_config
    __args__['schemaName'] = schema_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getFunctions:getFunctions', __args__, opts=opts, typ=GetFunctionsResult)
    return __ret__.apply(lambda __response__: GetFunctionsResult(
        catalog_name=pulumi.get(__response__, 'catalog_name'),
        functions=pulumi.get(__response__, 'functions'),
        id=pulumi.get(__response__, 'id'),
        include_browse=pulumi.get(__response__, 'include_browse'),
        provider_config=pulumi.get(__response__, 'provider_config'),
        schema_name=pulumi.get(__response__, 'schema_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MountArgs', 'Mount']

@pulumi.input_type
class MountArgs:
    def __init__(__self__, *,
                 abfs: Optional[pulumi.Input['MountAbfsArgs']] = None,
                 adl: Optional[pulumi.Input['MountAdlArgs']] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 encryption_type: Optional[pulumi.Input[_builtins.str]] = None,
                 extra_configs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 gs: Optional[pulumi.Input['MountGsArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['MountProviderConfigArgs']] = None,
                 resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 s3: Optional[pulumi.Input['MountS3Args']] = None,
                 uri: Optional[pulumi.Input[_builtins.str]] = None,
                 wasb: Optional[pulumi.Input['MountWasbArgs']] = None):
        """
        The set of arguments for constructing a Mount resource.
        """
        if abfs is not None:
            pulumi.set(__self__, "abfs", abfs)
        if adl is not None:
            pulumi.set(__self__, "adl", adl)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if encryption_type is not None:
            pulumi.set(__self__, "encryption_type", encryption_type)
        if extra_configs is not None:
            pulumi.set(__self__, "extra_configs", extra_configs)
        if gs is not None:
            pulumi.set(__self__, "gs", gs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)
        if s3 is not None:
            pulumi.set(__self__, "s3", s3)
        if uri is not None:
            pulumi.set(__self__, "uri", uri)
        if wasb is not None:
            pulumi.set(__self__, "wasb", wasb)

    @_builtins.property
    @pulumi.getter
    def abfs(self) -> Optional[pulumi.Input['MountAbfsArgs']]:
        return pulumi.get(self, "abfs")

    @abfs.setter
    def abfs(self, value: Optional[pulumi.Input['MountAbfsArgs']]):
        pulumi.set(self, "abfs", value)

    @_builtins.property
    @pulumi.getter
    def adl(self) -> Optional[pulumi.Input['MountAdlArgs']]:
        return pulumi.get(self, "adl")

    @adl.setter
    def adl(self, value: Optional[pulumi.Input['MountAdlArgs']]):
        pulumi.set(self, "adl", value)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="encryptionType")
    def encryption_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "encryption_type")

    @encryption_type.setter
    def encryption_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "encryption_type", value)

    @_builtins.property
    @pulumi.getter(name="extraConfigs")
    def extra_configs(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        return pulumi.get(self, "extra_configs")

    @extra_configs.setter
    def extra_configs(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "extra_configs", value)

    @_builtins.property
    @pulumi.getter
    def gs(self) -> Optional[pulumi.Input['MountGsArgs']]:
        return pulumi.get(self, "gs")

    @gs.setter
    def gs(self, value: Optional[pulumi.Input['MountGsArgs']]):
        pulumi.set(self, "gs", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['MountProviderConfigArgs']]:
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['MountProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_id", value)

    @_builtins.property
    @pulumi.getter
    def s3(self) -> Optional[pulumi.Input['MountS3Args']]:
        return pulumi.get(self, "s3")

    @s3.setter
    def s3(self, value: Optional[pulumi.Input['MountS3Args']]):
        pulumi.set(self, "s3", value)

    @_builtins.property
    @pulumi.getter
    def uri(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "uri")

    @uri.setter
    def uri(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "uri", value)

    @_builtins.property
    @pulumi.getter
    def wasb(self) -> Optional[pulumi.Input['MountWasbArgs']]:
        return pulumi.get(self, "wasb")

    @wasb.setter
    def wasb(self, value: Optional[pulumi.Input['MountWasbArgs']]):
        pulumi.set(self, "wasb", value)


@pulumi.input_type
class _MountState:
    def __init__(__self__, *,
                 abfs: Optional[pulumi.Input['MountAbfsArgs']] = None,
                 adl: Optional[pulumi.Input['MountAdlArgs']] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 encryption_type: Optional[pulumi.Input[_builtins.str]] = None,
                 extra_configs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 gs: Optional[pulumi.Input['MountGsArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['MountProviderConfigArgs']] = None,
                 resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 s3: Optional[pulumi.Input['MountS3Args']] = None,
                 source: Optional[pulumi.Input[_builtins.str]] = None,
                 uri: Optional[pulumi.Input[_builtins.str]] = None,
                 wasb: Optional[pulumi.Input['MountWasbArgs']] = None):
        """
        Input properties used for looking up and filtering Mount resources.
        :param pulumi.Input[_builtins.str] source: (String) HDFS-compatible url
        """
        if abfs is not None:
            pulumi.set(__self__, "abfs", abfs)
        if adl is not None:
            pulumi.set(__self__, "adl", adl)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if encryption_type is not None:
            pulumi.set(__self__, "encryption_type", encryption_type)
        if extra_configs is not None:
            pulumi.set(__self__, "extra_configs", extra_configs)
        if gs is not None:
            pulumi.set(__self__, "gs", gs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)
        if s3 is not None:
            pulumi.set(__self__, "s3", s3)
        if source is not None:
            pulumi.set(__self__, "source", source)
        if uri is not None:
            pulumi.set(__self__, "uri", uri)
        if wasb is not None:
            pulumi.set(__self__, "wasb", wasb)

    @_builtins.property
    @pulumi.getter
    def abfs(self) -> Optional[pulumi.Input['MountAbfsArgs']]:
        return pulumi.get(self, "abfs")

    @abfs.setter
    def abfs(self, value: Optional[pulumi.Input['MountAbfsArgs']]):
        pulumi.set(self, "abfs", value)

    @_builtins.property
    @pulumi.getter
    def adl(self) -> Optional[pulumi.Input['MountAdlArgs']]:
        return pulumi.get(self, "adl")

    @adl.setter
    def adl(self, value: Optional[pulumi.Input['MountAdlArgs']]):
        pulumi.set(self, "adl", value)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="encryptionType")
    def encryption_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "encryption_type")

    @encryption_type.setter
    def encryption_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "encryption_type", value)

    @_builtins.property
    @pulumi.getter(name="extraConfigs")
    def extra_configs(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        return pulumi.get(self, "extra_configs")

    @extra_configs.setter
    def extra_configs(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "extra_configs", value)

    @_builtins.property
    @pulumi.getter
    def gs(self) -> Optional[pulumi.Input['MountGsArgs']]:
        return pulumi.get(self, "gs")

    @gs.setter
    def gs(self, value: Optional[pulumi.Input['MountGsArgs']]):
        pulumi.set(self, "gs", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['MountProviderConfigArgs']]:
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['MountProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_id", value)

    @_builtins.property
    @pulumi.getter
    def s3(self) -> Optional[pulumi.Input['MountS3Args']]:
        return pulumi.get(self, "s3")

    @s3.setter
    def s3(self, value: Optional[pulumi.Input['MountS3Args']]):
        pulumi.set(self, "s3", value)

    @_builtins.property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (String) HDFS-compatible url
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "source", value)

    @_builtins.property
    @pulumi.getter
    def uri(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "uri")

    @uri.setter
    def uri(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "uri", value)

    @_builtins.property
    @pulumi.getter
    def wasb(self) -> Optional[pulumi.Input['MountWasbArgs']]:
        return pulumi.get(self, "wasb")

    @wasb.setter
    def wasb(self, value: Optional[pulumi.Input['MountWasbArgs']]):
        pulumi.set(self, "wasb", value)


@pulumi.type_token("databricks:index/mount:Mount")
class Mount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 abfs: Optional[pulumi.Input[Union['MountAbfsArgs', 'MountAbfsArgsDict']]] = None,
                 adl: Optional[pulumi.Input[Union['MountAdlArgs', 'MountAdlArgsDict']]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 encryption_type: Optional[pulumi.Input[_builtins.str]] = None,
                 extra_configs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 gs: Optional[pulumi.Input[Union['MountGsArgs', 'MountGsArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['MountProviderConfigArgs', 'MountProviderConfigArgsDict']]] = None,
                 resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 s3: Optional[pulumi.Input[Union['MountS3Args', 'MountS3ArgsDict']]] = None,
                 uri: Optional[pulumi.Input[_builtins.str]] = None,
                 wasb: Optional[pulumi.Input[Union['MountWasbArgs', 'MountWasbArgsDict']]] = None,
                 __props__=None):
        """
        > Please switch to databricks_volume. DBFS mounts are deprecated.

        > This resource can only be used with a workspace-level provider!

        > When `cluster_id` is not specified, it will create the smallest possible cluster in the default availability zone with name equal to or starting with `terraform-mount` for the shortest possible amount of time. To avoid mount failure due to potentially quota or capacity issues with the default cluster, we recommend specifying a cluster to use for mounting.

        > CRUD operations on a databricks mount require a running cluster. Due to limitations of terraform and the databricks mounts APIs, if the cluster the mount was most recently created / updated using no longer exists AND the mount is destroyed as a part of a pulumi up, we mark it as deleted without cleaning it up from the workspace.

        This resource will [mount your cloud storage](https://docs.databricks.com/data/databricks-file-system.html#mount-object-storage-to-dbfs) on `dbfs:/mnt/name`. Right now it supports mounting AWS S3, Azure (Blob Storage, ADLS Gen1 & Gen2), Google Cloud Storage.  It is important to understand that this will start up the cluster if the cluster is terminated. The read and refresh terraform command will require a cluster and may take some time to validate the mount.

        This resource provides two ways of mounting a storage account:

        1. Use a storage-specific configuration block - this could be used for the most cases, as it will fill most of the necessary details. Currently we support following configuration blocks:

        * `s3` - to [mount AWS S3](https://docs.databricks.com/data/data-sources/aws/amazon-s3.html)
        * `gs` - to [mount Google Cloud Storage](https://docs.gcp.databricks.com/data/data-sources/google/gcs.html)
        * `abfs` - to [mount ADLS Gen2](https://docs.microsoft.com/en-us/azure/databricks/data/data-sources/azure/adls-gen2/) using Azure Blob Filesystem (ABFS) driver
        * `adl` - to [mount ADLS Gen1](https://docs.microsoft.com/en-us/azure/databricks/data/data-sources/azure/azure-datalake) using Azure Data Lake (ADL) driver
        * `wasb`  - to [mount Azure Blob Storage](https://docs.microsoft.com/en-us/azure/databricks/data/data-sources/azure/azure-storage) using Windows Azure Storage Blob (WASB) driver

        1. Use generic arguments - you have a responsibility for providing all necessary parameters that are required to mount specific storage. This is most flexible option

        ## Common arguments

        * `cluster_id` - (Optional, String) Cluster to use for mounting. If no cluster is specified, a new cluster will be created and will mount the bucket for all of the clusters in this workspace. If the cluster is not running - it's going to be started, so be aware to set auto-termination rules on it.
        * `name` - (Optional, String) Name, under which mount will be accessible in `dbfs:/mnt/<MOUNT_NAME>`. If not specified, provider will try to infer it from depending on the resource type:
          * `bucket_name` for AWS S3 and Google Cloud Storage
          * `container_name` for ADLS Gen2 and Azure Blob Storage
          * `storage_resource_name` for ADLS Gen1
        * `uri` - (Optional, String) the URI for accessing specific storage (`s3a://....`, `abfss://....`, `gs://....`, etc.)
        * `extra_configs` - (Optional, String map) configuration parameters that are necessary for mounting of specific storage
        * `resource_id` - (Optional, String) resource ID for a given storage account. Could be used to fill defaults, such as storage account & container names on Azure.
        * `encryption_type` - (Optional, String) encryption type. Currently used only for [AWS S3 mounts](https://docs.databricks.com/data/data-sources/aws/amazon-s3.html#encrypt-data-in-s3-buckets)

        ### Example mounting ADLS Gen2 using uri and extra_configs

        ```python
        import pulumi
        import pulumi_databricks as databricks

        tenant_id = "00000000-1111-2222-3333-444444444444"
        client_id = "55555555-6666-7777-8888-999999999999"
        secret_scope = "some-kv"
        secret_key = "some-sp-secret"
        container = "test"
        storage_acc = "lrs"
        this = databricks.Mount("this",
            name="tf-abfss",
            uri=f"abfss://{container}@{storage_acc}.dfs.core.windows.net",
            extra_configs={
                "fs.azure.account.auth.type": "OAuth",
                "fs.azure.account.oauth.provider.type": "org.apache.hadoop.fs.azurebfs.oauth2.ClientCredsTokenProvider",
                "fs.azure.account.oauth2.client.id": client_id,
                "fs.azure.account.oauth2.client.secret": f"{{{{secrets/{secret_scope}/{secret_key}}}}}",
                "fs.azure.account.oauth2.client.endpoint": f"https://login.microsoftonline.com/{tenant_id}/oauth2/token",
                "fs.azure.createRemoteFileSystemDuringInitialization": "false",
            })
        ```

        ### Example mounting ADLS Gen2 with AAD passthrough

        > AAD passthrough is considered a legacy data access pattern. Use Unity Catalog for fine-grained data access control.

        > Mounts using AAD passthrough cannot be created using a service principal.

        To mount ALDS Gen2 with Azure Active Directory Credentials passthrough we need to execute the mount commands using the cluster configured with AAD Credentials passthrough & provide necessary configuration parameters (see [documentation](https://docs.microsoft.com/en-us/azure/databricks/security/credential-passthrough/adls-passthrough#--mount-azure-data-lake-storage-to-dbfs-using-credential-passthrough) for more details).

        ```python
        import pulumi
        import pulumi_azurerm as azurerm
        import pulumi_databricks as databricks

        config = pulumi.Config()
        # Resource group for Databricks Workspace
        resource_group = config.require("resourceGroup")
        # Name of the Databricks Workspace
        workspace_name = config.require("workspaceName")
        this = azurerm.index.databricks_workspace(name=workspace_name,
            resource_group_name=resource_group)
        smallest = databricks.get_node_type(local_disk=True)
        latest = databricks.get_spark_version()
        shared_passthrough = databricks.Cluster("shared_passthrough",
            cluster_name="Shared Passthrough for mount",
            spark_version=latest.id,
            node_type_id=smallest.id,
            autotermination_minutes=10,
            num_workers=1,
            spark_conf={
                "spark.databricks.cluster.profile": "serverless",
                "spark.databricks.repl.allowedLanguages": "python,sql",
                "spark.databricks.passthrough.enabled": "true",
                "spark.databricks.pyspark.enableProcessIsolation": "true",
            },
            custom_tags={
                "ResourceClass": "Serverless",
            })
        # Name of the ADLS Gen2 storage container
        storage_acc = config.require("storageAcc")
        # Name of container inside storage account
        container = config.require("container")
        passthrough = databricks.Mount("passthrough",
            name="passthrough-test",
            cluster_id=shared_passthrough.id,
            uri=f"abfss://{container}@{storage_acc}.dfs.core.windows.net",
            extra_configs={
                "fs.azure.account.auth.type": "CustomAccessToken",
                "fs.azure.account.custom.token.provider.class": "{{sparkconf/spark.databricks.passthrough.adls.gen2.tokenProviderClassName}}",
            })
        ```

        ## s3 block

        This block allows specifying parameters for mounting of the ADLS Gen2. The following arguments are required inside the `s3` block:

        * `instance_profile` - (Optional) (String) ARN of registered instance profile for data access.  If it's not specified, then the `cluster_id` should be provided, and the cluster should have an instance profile attached to it. If both `cluster_id` & `instance_profile` are specified, then `cluster_id` takes precedence.
        * `bucket_name` - (Required) (String) S3 bucket name to be mounted.

        ### Example of mounting S3

        ```python
        import pulumi
        import pulumi_databricks as databricks

        # now you can do `%fs ls /mnt/experiments` in notebooks
        this = databricks.Mount("this",
            name="experiments",
            s3={
                "instance_profile": ds["id"],
                "bucket_name": this_aws_s3_bucket["bucket"],
            })
        ```

        ## abfs block

        This block allows specifying parameters for mounting of the ADLS Gen2. The following arguments are required inside the `abfs` block:

        * `client_id` - (Required) (String) This is the client_id (Application Object ID) for the enterprise application for the service principal.
        * `tenant_id` - (Optional) (String) This is your azure directory tenant id. It is required for creating the mount. (Could be omitted if Azure authentication is used, and we can extract `tenant_id` from it).
        * `client_secret_key` - (Required) (String) This is the secret key in which your service principal/enterprise app client secret will be stored.
        * `client_secret_scope` - (Required) (String) This is the secret scope in which your service principal/enterprise app client secret will be stored.
        * `container_name` - (Required) (String) ADLS gen2 container name. (Could be omitted if `resource_id` is provided)
        * `storage_account_name` - (Required) (String) The name of the storage resource in which the data is. (Could be omitted if `resource_id` is provided)
        * `directory` - (Computed) (String) This is optional if you don't want to add an additional directory that you wish to mount. This must start with a "/".
        * `initialize_file_system` - (Required) (Bool) either or not initialize FS for the first use

        ### Creating mount for ADLS Gen2 using abfs block

        In this example, we're using Azure authentication, so we can omit some parameters (`tenant_id`, `storage_account_name`, and `container_name`) that will be detected automatically.

        ```python
        import pulumi
        import pulumi_azurerm as azurerm
        import pulumi_databricks as databricks

        terraform = databricks.SecretScope("terraform",
            name="application",
            initial_manage_principal="users")
        service_principal_key = databricks.Secret("service_principal_key",
            key="service_principal_key",
            string_value=ar_m__clien_t__secret,
            scope=terraform.name)
        this = azurerm.index.StorageAccount("this",
            name=f{prefix}datalake,
            resource_group_name=resource_group_name,
            location=resource_group_location,
            account_tier=Standard,
            account_replication_type=GRS,
            account_kind=StorageV2,
            is_hns_enabled=True)
        this_role_assignment = azurerm.index.RoleAssignment("this",
            scope=this.id,
            role_definition_name=Storage Blob Data Contributor,
            principal_id=current.object_id)
        this_storage_container = azurerm.index.StorageContainer("this",
            name=marketing,
            storage_account_name=this.name,
            container_access_type=private)
        marketing = databricks.Mount("marketing",
            name="marketing",
            resource_id=this_storage_container["resourceManagerId"],
            abfs={
                "client_id": current["clientId"],
                "client_secret_scope": terraform.name,
                "client_secret_key": service_principal_key.key,
                "initialize_file_system": True,
            })
        ```

        ## gs block

        This block allows specifying parameters for mounting of the Google Cloud Storage. The following arguments are required inside the `gs` block:

        * `service_account` - (Optional) (String) email of registered [Google Service Account](https://docs.gcp.databricks.com/data/data-sources/google/gcs.html#step-1-set-up-google-cloud-service-account-using-google-cloud-console) for data access.  If it's not specified, then the `cluster_id` should be provided, and the cluster should have a Google service account attached to it.
        * `bucket_name` - (Required) (String) GCS bucket name to be mounted.

        ### Example mounting Google Cloud Storage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this_gs = databricks.Mount("this_gs",
            name="gs-mount",
            gs={
                "service_account": "acc@company.iam.gserviceaccount.com",
                "bucket_name": "mybucket",
            })
        ```

        ## adl block

        This block allows specifying parameters for mounting of the ADLS Gen1. The following arguments are required inside the `adl` block:

        * `client_id` - (Required) (String) This is the client_id for the enterprise application for the service principal.
        * `tenant_id` - (Optional) (String) This is your azure directory tenant id. It is required for creating the mount. (Could be omitted if Azure authentication is used, and we can extract `tenant_id` from it)
        * `client_secret_key` - (Required) (String) This is the secret key in which your service principal/enterprise app client secret will be stored.
        * `client_secret_scope` - (Required) (String) This is the secret scope in which your service principal/enterprise app client secret will be stored.

        * `storage_resource_name` - (Required) (String) The name of the storage resource in which the data is for ADLS gen 1. This is what you are trying to mount. (Could be omitted if `resource_id` is provided)
        * `spark_conf_prefix` - (Optional) (String) This is the spark configuration prefix for adls gen 1 mount. The options are `fs.adl`, `dfs.adls`. Use `fs.adl` for runtime 6.0 and above for the clusters. Otherwise use `dfs.adls`. The default value is: `fs.adl`.
        * `directory` - (Computed) (String) This is optional if you don't want to add an additional directory that you wish to mount. This must start with a "/".

        ### Example mounting ADLS Gen1

        ```python
        import pulumi
        import pulumi_databricks as databricks

        mount = databricks.Mount("mount",
            name="{var.RANDOM}",
            adl={
                "storage_resource_name": "{env.TEST_STORAGE_ACCOUNT_NAME}",
                "tenant_id": current["tenantId"],
                "client_id": current["clientId"],
                "client_secret_scope": terraform["name"],
                "client_secret_key": service_principal_key["key"],
                "spark_conf_prefix": "fs.adl",
            })
        ```

        ## wasb block

        This block allows specifying parameters for mounting of the Azure Blob Storage. The following arguments are required inside the `wasb` block:

        * `auth_type` - (Required) (String) This is the auth type for blob storage. This can either be SAS tokens (`SAS`) or account access keys (`ACCESS_KEY`).
        * `token_secret_scope` - (Required) (String) This is the secret scope in which your auth type token is stored.
        * `token_secret_key` - (Required) (String) This is the secret key in which your auth type token is stored.
        * `container_name` - (Required) (String) The container in which the data is. This is what you are trying to mount. (Could be omitted if `resource_id` is provided)
        * `storage_account_name` - (Required) (String) The name of the storage resource in which the data is. (Could be omitted if `resource_id` is provided)
        * `directory` - (Computed) (String) This is optional if you don't want to add an additional directory that you wish to mount. This must start with a "/".

        ### Example mounting Azure Blob Storage

        ```python
        import pulumi
        import pulumi_azurerm as azurerm
        import pulumi_databricks as databricks

        blobaccount = azurerm.index.StorageAccount("blobaccount",
            name=f{prefix}blob,
            resource_group_name=resource_group_name,
            location=resource_group_location,
            account_tier=Standard,
            account_replication_type=LRS,
            account_kind=StorageV2)
        marketing = azurerm.index.StorageContainer("marketing",
            name=marketing,
            storage_account_name=blobaccount.name,
            container_access_type=private)
        terraform = databricks.SecretScope("terraform",
            name="application",
            initial_manage_principal="users")
        storage_key = databricks.Secret("storage_key",
            key="blob_storage_key",
            string_value=blobaccount["primaryAccessKey"],
            scope=terraform.name)
        marketing_mount = databricks.Mount("marketing",
            name="marketing",
            wasb={
                "container_name": marketing["name"],
                "storage_account_name": blobaccount["name"],
                "auth_type": "ACCESS_KEY",
                "token_secret_scope": terraform.name,
                "token_secret_key": storage_key.key,
            })
        ```

        * `provider_config` - (Optional) Configure the provider for management through account provider. This block consists of the following fields:
          * `workspace_id` - (Required) Workspace ID which the resource belongs to. This workspace must be part of the account which the provider is configured with.

        ## Migration from other mount resources

        Migration from the specific mount resource is straightforward:

        * rename `mount_name` to `name`
        * wrap storage-specific settings (`container_name`, ...) into corresponding block (`adl`, `abfs`, `s3`, `wasbs`)
        * for S3 mounts, rename `s3_bucket_name` to `bucket_name`

        ## Related Resources

        The following resources are often used in the same context:

        * End to end workspace management guide.
        * get_aws_bucket_policy data to configure a simple access policy for AWS S3 buckets, so that Databricks can access data in it.
        * Cluster to create [Databricks Clusters](https://docs.databricks.com/clusters/index.html).
        * DbfsFile data to get file content from [Databricks File System (DBFS)](https://docs.databricks.com/data/databricks-file-system.html).
        * get_dbfs_file_paths data to get list of file names from get file content from [Databricks File System (DBFS)](https://docs.databricks.com/data/databricks-file-system.html).
        * DbfsFile to manage relatively small files on [Databricks File System (DBFS)](https://docs.databricks.com/data/databricks-file-system.html).
        * InstanceProfile to manage AWS EC2 instance profiles that users can launch Cluster and access data, like databricks_mount.
        * Library to install a [library](https://docs.databricks.com/libraries/index.html) on databricks_cluster.

        ## Import

        !> Importing this resource is not currently supported.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[MountArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        > Please switch to databricks_volume. DBFS mounts are deprecated.

        > This resource can only be used with a workspace-level provider!

        > When `cluster_id` is not specified, it will create the smallest possible cluster in the default availability zone with name equal to or starting with `terraform-mount` for the shortest possible amount of time. To avoid mount failure due to potentially quota or capacity issues with the default cluster, we recommend specifying a cluster to use for mounting.

        > CRUD operations on a databricks mount require a running cluster. Due to limitations of terraform and the databricks mounts APIs, if the cluster the mount was most recently created / updated using no longer exists AND the mount is destroyed as a part of a pulumi up, we mark it as deleted without cleaning it up from the workspace.

        This resource will [mount your cloud storage](https://docs.databricks.com/data/databricks-file-system.html#mount-object-storage-to-dbfs) on `dbfs:/mnt/name`. Right now it supports mounting AWS S3, Azure (Blob Storage, ADLS Gen1 & Gen2), Google Cloud Storage.  It is important to understand that this will start up the cluster if the cluster is terminated. The read and refresh terraform command will require a cluster and may take some time to validate the mount.

        This resource provides two ways of mounting a storage account:

        1. Use a storage-specific configuration block - this could be used for the most cases, as it will fill most of the necessary details. Currently we support following configuration blocks:

        * `s3` - to [mount AWS S3](https://docs.databricks.com/data/data-sources/aws/amazon-s3.html)
        * `gs` - to [mount Google Cloud Storage](https://docs.gcp.databricks.com/data/data-sources/google/gcs.html)
        * `abfs` - to [mount ADLS Gen2](https://docs.microsoft.com/en-us/azure/databricks/data/data-sources/azure/adls-gen2/) using Azure Blob Filesystem (ABFS) driver
        * `adl` - to [mount ADLS Gen1](https://docs.microsoft.com/en-us/azure/databricks/data/data-sources/azure/azure-datalake) using Azure Data Lake (ADL) driver
        * `wasb`  - to [mount Azure Blob Storage](https://docs.microsoft.com/en-us/azure/databricks/data/data-sources/azure/azure-storage) using Windows Azure Storage Blob (WASB) driver

        1. Use generic arguments - you have a responsibility for providing all necessary parameters that are required to mount specific storage. This is most flexible option

        ## Common arguments

        * `cluster_id` - (Optional, String) Cluster to use for mounting. If no cluster is specified, a new cluster will be created and will mount the bucket for all of the clusters in this workspace. If the cluster is not running - it's going to be started, so be aware to set auto-termination rules on it.
        * `name` - (Optional, String) Name, under which mount will be accessible in `dbfs:/mnt/<MOUNT_NAME>`. If not specified, provider will try to infer it from depending on the resource type:
          * `bucket_name` for AWS S3 and Google Cloud Storage
          * `container_name` for ADLS Gen2 and Azure Blob Storage
          * `storage_resource_name` for ADLS Gen1
        * `uri` - (Optional, String) the URI for accessing specific storage (`s3a://....`, `abfss://....`, `gs://....`, etc.)
        * `extra_configs` - (Optional, String map) configuration parameters that are necessary for mounting of specific storage
        * `resource_id` - (Optional, String) resource ID for a given storage account. Could be used to fill defaults, such as storage account & container names on Azure.
        * `encryption_type` - (Optional, String) encryption type. Currently used only for [AWS S3 mounts](https://docs.databricks.com/data/data-sources/aws/amazon-s3.html#encrypt-data-in-s3-buckets)

        ### Example mounting ADLS Gen2 using uri and extra_configs

        ```python
        import pulumi
        import pulumi_databricks as databricks

        tenant_id = "00000000-1111-2222-3333-444444444444"
        client_id = "55555555-6666-7777-8888-999999999999"
        secret_scope = "some-kv"
        secret_key = "some-sp-secret"
        container = "test"
        storage_acc = "lrs"
        this = databricks.Mount("this",
            name="tf-abfss",
            uri=f"abfss://{container}@{storage_acc}.dfs.core.windows.net",
            extra_configs={
                "fs.azure.account.auth.type": "OAuth",
                "fs.azure.account.oauth.provider.type": "org.apache.hadoop.fs.azurebfs.oauth2.ClientCredsTokenProvider",
                "fs.azure.account.oauth2.client.id": client_id,
                "fs.azure.account.oauth2.client.secret": f"{{{{secrets/{secret_scope}/{secret_key}}}}}",
                "fs.azure.account.oauth2.client.endpoint": f"https://login.microsoftonline.com/{tenant_id}/oauth2/token",
                "fs.azure.createRemoteFileSystemDuringInitialization": "false",
            })
        ```

        ### Example mounting ADLS Gen2 with AAD passthrough

        > AAD passthrough is considered a legacy data access pattern. Use Unity Catalog for fine-grained data access control.

        > Mounts using AAD passthrough cannot be created using a service principal.

        To mount ALDS Gen2 with Azure Active Directory Credentials passthrough we need to execute the mount commands using the cluster configured with AAD Credentials passthrough & provide necessary configuration parameters (see [documentation](https://docs.microsoft.com/en-us/azure/databricks/security/credential-passthrough/adls-passthrough#--mount-azure-data-lake-storage-to-dbfs-using-credential-passthrough) for more details).

        ```python
        import pulumi
        import pulumi_azurerm as azurerm
        import pulumi_databricks as databricks

        config = pulumi.Config()
        # Resource group for Databricks Workspace
        resource_group = config.require("resourceGroup")
        # Name of the Databricks Workspace
        workspace_name = config.require("workspaceName")
        this = azurerm.index.databricks_workspace(name=workspace_name,
            resource_group_name=resource_group)
        smallest = databricks.get_node_type(local_disk=True)
        latest = databricks.get_spark_version()
        shared_passthrough = databricks.Cluster("shared_passthrough",
            cluster_name="Shared Passthrough for mount",
            spark_version=latest.id,
            node_type_id=smallest.id,
            autotermination_minutes=10,
            num_workers=1,
            spark_conf={
                "spark.databricks.cluster.profile": "serverless",
                "spark.databricks.repl.allowedLanguages": "python,sql",
                "spark.databricks.passthrough.enabled": "true",
                "spark.databricks.pyspark.enableProcessIsolation": "true",
            },
            custom_tags={
                "ResourceClass": "Serverless",
            })
        # Name of the ADLS Gen2 storage container
        storage_acc = config.require("storageAcc")
        # Name of container inside storage account
        container = config.require("container")
        passthrough = databricks.Mount("passthrough",
            name="passthrough-test",
            cluster_id=shared_passthrough.id,
            uri=f"abfss://{container}@{storage_acc}.dfs.core.windows.net",
            extra_configs={
                "fs.azure.account.auth.type": "CustomAccessToken",
                "fs.azure.account.custom.token.provider.class": "{{sparkconf/spark.databricks.passthrough.adls.gen2.tokenProviderClassName}}",
            })
        ```

        ## s3 block

        This block allows specifying parameters for mounting of the ADLS Gen2. The following arguments are required inside the `s3` block:

        * `instance_profile` - (Optional) (String) ARN of registered instance profile for data access.  If it's not specified, then the `cluster_id` should be provided, and the cluster should have an instance profile attached to it. If both `cluster_id` & `instance_profile` are specified, then `cluster_id` takes precedence.
        * `bucket_name` - (Required) (String) S3 bucket name to be mounted.

        ### Example of mounting S3

        ```python
        import pulumi
        import pulumi_databricks as databricks

        # now you can do `%fs ls /mnt/experiments` in notebooks
        this = databricks.Mount("this",
            name="experiments",
            s3={
                "instance_profile": ds["id"],
                "bucket_name": this_aws_s3_bucket["bucket"],
            })
        ```

        ## abfs block

        This block allows specifying parameters for mounting of the ADLS Gen2. The following arguments are required inside the `abfs` block:

        * `client_id` - (Required) (String) This is the client_id (Application Object ID) for the enterprise application for the service principal.
        * `tenant_id` - (Optional) (String) This is your azure directory tenant id. It is required for creating the mount. (Could be omitted if Azure authentication is used, and we can extract `tenant_id` from it).
        * `client_secret_key` - (Required) (String) This is the secret key in which your service principal/enterprise app client secret will be stored.
        * `client_secret_scope` - (Required) (String) This is the secret scope in which your service principal/enterprise app client secret will be stored.
        * `container_name` - (Required) (String) ADLS gen2 container name. (Could be omitted if `resource_id` is provided)
        * `storage_account_name` - (Required) (String) The name of the storage resource in which the data is. (Could be omitted if `resource_id` is provided)
        * `directory` - (Computed) (String) This is optional if you don't want to add an additional directory that you wish to mount. This must start with a "/".
        * `initialize_file_system` - (Required) (Bool) either or not initialize FS for the first use

        ### Creating mount for ADLS Gen2 using abfs block

        In this example, we're using Azure authentication, so we can omit some parameters (`tenant_id`, `storage_account_name`, and `container_name`) that will be detected automatically.

        ```python
        import pulumi
        import pulumi_azurerm as azurerm
        import pulumi_databricks as databricks

        terraform = databricks.SecretScope("terraform",
            name="application",
            initial_manage_principal="users")
        service_principal_key = databricks.Secret("service_principal_key",
            key="service_principal_key",
            string_value=ar_m__clien_t__secret,
            scope=terraform.name)
        this = azurerm.index.StorageAccount("this",
            name=f{prefix}datalake,
            resource_group_name=resource_group_name,
            location=resource_group_location,
            account_tier=Standard,
            account_replication_type=GRS,
            account_kind=StorageV2,
            is_hns_enabled=True)
        this_role_assignment = azurerm.index.RoleAssignment("this",
            scope=this.id,
            role_definition_name=Storage Blob Data Contributor,
            principal_id=current.object_id)
        this_storage_container = azurerm.index.StorageContainer("this",
            name=marketing,
            storage_account_name=this.name,
            container_access_type=private)
        marketing = databricks.Mount("marketing",
            name="marketing",
            resource_id=this_storage_container["resourceManagerId"],
            abfs={
                "client_id": current["clientId"],
                "client_secret_scope": terraform.name,
                "client_secret_key": service_principal_key.key,
                "initialize_file_system": True,
            })
        ```

        ## gs block

        This block allows specifying parameters for mounting of the Google Cloud Storage. The following arguments are required inside the `gs` block:

        * `service_account` - (Optional) (String) email of registered [Google Service Account](https://docs.gcp.databricks.com/data/data-sources/google/gcs.html#step-1-set-up-google-cloud-service-account-using-google-cloud-console) for data access.  If it's not specified, then the `cluster_id` should be provided, and the cluster should have a Google service account attached to it.
        * `bucket_name` - (Required) (String) GCS bucket name to be mounted.

        ### Example mounting Google Cloud Storage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this_gs = databricks.Mount("this_gs",
            name="gs-mount",
            gs={
                "service_account": "acc@company.iam.gserviceaccount.com",
                "bucket_name": "mybucket",
            })
        ```

        ## adl block

        This block allows specifying parameters for mounting of the ADLS Gen1. The following arguments are required inside the `adl` block:

        * `client_id` - (Required) (String) This is the client_id for the enterprise application for the service principal.
        * `tenant_id` - (Optional) (String) This is your azure directory tenant id. It is required for creating the mount. (Could be omitted if Azure authentication is used, and we can extract `tenant_id` from it)
        * `client_secret_key` - (Required) (String) This is the secret key in which your service principal/enterprise app client secret will be stored.
        * `client_secret_scope` - (Required) (String) This is the secret scope in which your service principal/enterprise app client secret will be stored.

        * `storage_resource_name` - (Required) (String) The name of the storage resource in which the data is for ADLS gen 1. This is what you are trying to mount. (Could be omitted if `resource_id` is provided)
        * `spark_conf_prefix` - (Optional) (String) This is the spark configuration prefix for adls gen 1 mount. The options are `fs.adl`, `dfs.adls`. Use `fs.adl` for runtime 6.0 and above for the clusters. Otherwise use `dfs.adls`. The default value is: `fs.adl`.
        * `directory` - (Computed) (String) This is optional if you don't want to add an additional directory that you wish to mount. This must start with a "/".

        ### Example mounting ADLS Gen1

        ```python
        import pulumi
        import pulumi_databricks as databricks

        mount = databricks.Mount("mount",
            name="{var.RANDOM}",
            adl={
                "storage_resource_name": "{env.TEST_STORAGE_ACCOUNT_NAME}",
                "tenant_id": current["tenantId"],
                "client_id": current["clientId"],
                "client_secret_scope": terraform["name"],
                "client_secret_key": service_principal_key["key"],
                "spark_conf_prefix": "fs.adl",
            })
        ```

        ## wasb block

        This block allows specifying parameters for mounting of the Azure Blob Storage. The following arguments are required inside the `wasb` block:

        * `auth_type` - (Required) (String) This is the auth type for blob storage. This can either be SAS tokens (`SAS`) or account access keys (`ACCESS_KEY`).
        * `token_secret_scope` - (Required) (String) This is the secret scope in which your auth type token is stored.
        * `token_secret_key` - (Required) (String) This is the secret key in which your auth type token is stored.
        * `container_name` - (Required) (String) The container in which the data is. This is what you are trying to mount. (Could be omitted if `resource_id` is provided)
        * `storage_account_name` - (Required) (String) The name of the storage resource in which the data is. (Could be omitted if `resource_id` is provided)
        * `directory` - (Computed) (String) This is optional if you don't want to add an additional directory that you wish to mount. This must start with a "/".

        ### Example mounting Azure Blob Storage

        ```python
        import pulumi
        import pulumi_azurerm as azurerm
        import pulumi_databricks as databricks

        blobaccount = azurerm.index.StorageAccount("blobaccount",
            name=f{prefix}blob,
            resource_group_name=resource_group_name,
            location=resource_group_location,
            account_tier=Standard,
            account_replication_type=LRS,
            account_kind=StorageV2)
        marketing = azurerm.index.StorageContainer("marketing",
            name=marketing,
            storage_account_name=blobaccount.name,
            container_access_type=private)
        terraform = databricks.SecretScope("terraform",
            name="application",
            initial_manage_principal="users")
        storage_key = databricks.Secret("storage_key",
            key="blob_storage_key",
            string_value=blobaccount["primaryAccessKey"],
            scope=terraform.name)
        marketing_mount = databricks.Mount("marketing",
            name="marketing",
            wasb={
                "container_name": marketing["name"],
                "storage_account_name": blobaccount["name"],
                "auth_type": "ACCESS_KEY",
                "token_secret_scope": terraform.name,
                "token_secret_key": storage_key.key,
            })
        ```

        * `provider_config` - (Optional) Configure the provider for management through account provider. This block consists of the following fields:
          * `workspace_id` - (Required) Workspace ID which the resource belongs to. This workspace must be part of the account which the provider is configured with.

        ## Migration from other mount resources

        Migration from the specific mount resource is straightforward:

        * rename `mount_name` to `name`
        * wrap storage-specific settings (`container_name`, ...) into corresponding block (`adl`, `abfs`, `s3`, `wasbs`)
        * for S3 mounts, rename `s3_bucket_name` to `bucket_name`

        ## Related Resources

        The following resources are often used in the same context:

        * End to end workspace management guide.
        * get_aws_bucket_policy data to configure a simple access policy for AWS S3 buckets, so that Databricks can access data in it.
        * Cluster to create [Databricks Clusters](https://docs.databricks.com/clusters/index.html).
        * DbfsFile data to get file content from [Databricks File System (DBFS)](https://docs.databricks.com/data/databricks-file-system.html).
        * get_dbfs_file_paths data to get list of file names from get file content from [Databricks File System (DBFS)](https://docs.databricks.com/data/databricks-file-system.html).
        * DbfsFile to manage relatively small files on [Databricks File System (DBFS)](https://docs.databricks.com/data/databricks-file-system.html).
        * InstanceProfile to manage AWS EC2 instance profiles that users can launch Cluster and access data, like databricks_mount.
        * Library to install a [library](https://docs.databricks.com/libraries/index.html) on databricks_cluster.

        ## Import

        !> Importing this resource is not currently supported.

        :param str resource_name: The name of the resource.
        :param MountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 abfs: Optional[pulumi.Input[Union['MountAbfsArgs', 'MountAbfsArgsDict']]] = None,
                 adl: Optional[pulumi.Input[Union['MountAdlArgs', 'MountAdlArgsDict']]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 encryption_type: Optional[pulumi.Input[_builtins.str]] = None,
                 extra_configs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 gs: Optional[pulumi.Input[Union['MountGsArgs', 'MountGsArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['MountProviderConfigArgs', 'MountProviderConfigArgsDict']]] = None,
                 resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 s3: Optional[pulumi.Input[Union['MountS3Args', 'MountS3ArgsDict']]] = None,
                 uri: Optional[pulumi.Input[_builtins.str]] = None,
                 wasb: Optional[pulumi.Input[Union['MountWasbArgs', 'MountWasbArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MountArgs.__new__(MountArgs)

            __props__.__dict__["abfs"] = abfs
            __props__.__dict__["adl"] = adl
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["encryption_type"] = encryption_type
            __props__.__dict__["extra_configs"] = extra_configs
            __props__.__dict__["gs"] = gs
            __props__.__dict__["name"] = name
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["resource_id"] = resource_id
            __props__.__dict__["s3"] = s3
            __props__.__dict__["uri"] = uri
            __props__.__dict__["wasb"] = wasb
            __props__.__dict__["source"] = None
        super(Mount, __self__).__init__(
            'databricks:index/mount:Mount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            abfs: Optional[pulumi.Input[Union['MountAbfsArgs', 'MountAbfsArgsDict']]] = None,
            adl: Optional[pulumi.Input[Union['MountAdlArgs', 'MountAdlArgsDict']]] = None,
            cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
            encryption_type: Optional[pulumi.Input[_builtins.str]] = None,
            extra_configs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            gs: Optional[pulumi.Input[Union['MountGsArgs', 'MountGsArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['MountProviderConfigArgs', 'MountProviderConfigArgsDict']]] = None,
            resource_id: Optional[pulumi.Input[_builtins.str]] = None,
            s3: Optional[pulumi.Input[Union['MountS3Args', 'MountS3ArgsDict']]] = None,
            source: Optional[pulumi.Input[_builtins.str]] = None,
            uri: Optional[pulumi.Input[_builtins.str]] = None,
            wasb: Optional[pulumi.Input[Union['MountWasbArgs', 'MountWasbArgsDict']]] = None) -> 'Mount':
        """
        Get an existing Mount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] source: (String) HDFS-compatible url
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MountState.__new__(_MountState)

        __props__.__dict__["abfs"] = abfs
        __props__.__dict__["adl"] = adl
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["encryption_type"] = encryption_type
        __props__.__dict__["extra_configs"] = extra_configs
        __props__.__dict__["gs"] = gs
        __props__.__dict__["name"] = name
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["resource_id"] = resource_id
        __props__.__dict__["s3"] = s3
        __props__.__dict__["source"] = source
        __props__.__dict__["uri"] = uri
        __props__.__dict__["wasb"] = wasb
        return Mount(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def abfs(self) -> pulumi.Output[Optional['outputs.MountAbfs']]:
        return pulumi.get(self, "abfs")

    @_builtins.property
    @pulumi.getter
    def adl(self) -> pulumi.Output[Optional['outputs.MountAdl']]:
        return pulumi.get(self, "adl")

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter(name="encryptionType")
    def encryption_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "encryption_type")

    @_builtins.property
    @pulumi.getter(name="extraConfigs")
    def extra_configs(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        return pulumi.get(self, "extra_configs")

    @_builtins.property
    @pulumi.getter
    def gs(self) -> pulumi.Output[Optional['outputs.MountGs']]:
        return pulumi.get(self, "gs")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.MountProviderConfig']]:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "resource_id")

    @_builtins.property
    @pulumi.getter
    def s3(self) -> pulumi.Output[Optional['outputs.MountS3']]:
        return pulumi.get(self, "s3")

    @_builtins.property
    @pulumi.getter
    def source(self) -> pulumi.Output[_builtins.str]:
        """
        (String) HDFS-compatible url
        """
        return pulumi.get(self, "source")

    @_builtins.property
    @pulumi.getter
    def uri(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "uri")

    @_builtins.property
    @pulumi.getter
    def wasb(self) -> pulumi.Output[Optional['outputs.MountWasb']]:
        return pulumi.get(self, "wasb")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetSqlWarehouseResult',
    'AwaitableGetSqlWarehouseResult',
    'get_sql_warehouse',
    'get_sql_warehouse_output',
]

@pulumi.output_type
class GetSqlWarehouseResult:
    """
    A collection of values returned by getSqlWarehouse.
    """
    def __init__(__self__, auto_stop_mins=None, channel=None, cluster_size=None, creator_name=None, data_source_id=None, enable_photon=None, enable_serverless_compute=None, health=None, id=None, instance_profile_arn=None, jdbc_url=None, max_num_clusters=None, min_num_clusters=None, name=None, num_active_sessions=None, num_clusters=None, odbc_params=None, provider_config=None, spot_instance_policy=None, state=None, tags=None, warehouse_type=None):
        if auto_stop_mins and not isinstance(auto_stop_mins, int):
            raise TypeError("Expected argument 'auto_stop_mins' to be a int")
        pulumi.set(__self__, "auto_stop_mins", auto_stop_mins)
        if channel and not isinstance(channel, dict):
            raise TypeError("Expected argument 'channel' to be a dict")
        pulumi.set(__self__, "channel", channel)
        if cluster_size and not isinstance(cluster_size, str):
            raise TypeError("Expected argument 'cluster_size' to be a str")
        pulumi.set(__self__, "cluster_size", cluster_size)
        if creator_name and not isinstance(creator_name, str):
            raise TypeError("Expected argument 'creator_name' to be a str")
        pulumi.set(__self__, "creator_name", creator_name)
        if data_source_id and not isinstance(data_source_id, str):
            raise TypeError("Expected argument 'data_source_id' to be a str")
        pulumi.set(__self__, "data_source_id", data_source_id)
        if enable_photon and not isinstance(enable_photon, bool):
            raise TypeError("Expected argument 'enable_photon' to be a bool")
        pulumi.set(__self__, "enable_photon", enable_photon)
        if enable_serverless_compute and not isinstance(enable_serverless_compute, bool):
            raise TypeError("Expected argument 'enable_serverless_compute' to be a bool")
        pulumi.set(__self__, "enable_serverless_compute", enable_serverless_compute)
        if health and not isinstance(health, dict):
            raise TypeError("Expected argument 'health' to be a dict")
        pulumi.set(__self__, "health", health)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_profile_arn and not isinstance(instance_profile_arn, str):
            raise TypeError("Expected argument 'instance_profile_arn' to be a str")
        pulumi.set(__self__, "instance_profile_arn", instance_profile_arn)
        if jdbc_url and not isinstance(jdbc_url, str):
            raise TypeError("Expected argument 'jdbc_url' to be a str")
        pulumi.set(__self__, "jdbc_url", jdbc_url)
        if max_num_clusters and not isinstance(max_num_clusters, int):
            raise TypeError("Expected argument 'max_num_clusters' to be a int")
        pulumi.set(__self__, "max_num_clusters", max_num_clusters)
        if min_num_clusters and not isinstance(min_num_clusters, int):
            raise TypeError("Expected argument 'min_num_clusters' to be a int")
        pulumi.set(__self__, "min_num_clusters", min_num_clusters)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if num_active_sessions and not isinstance(num_active_sessions, int):
            raise TypeError("Expected argument 'num_active_sessions' to be a int")
        pulumi.set(__self__, "num_active_sessions", num_active_sessions)
        if num_clusters and not isinstance(num_clusters, int):
            raise TypeError("Expected argument 'num_clusters' to be a int")
        pulumi.set(__self__, "num_clusters", num_clusters)
        if odbc_params and not isinstance(odbc_params, dict):
            raise TypeError("Expected argument 'odbc_params' to be a dict")
        pulumi.set(__self__, "odbc_params", odbc_params)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)
        if spot_instance_policy and not isinstance(spot_instance_policy, str):
            raise TypeError("Expected argument 'spot_instance_policy' to be a str")
        pulumi.set(__self__, "spot_instance_policy", spot_instance_policy)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if warehouse_type and not isinstance(warehouse_type, str):
            raise TypeError("Expected argument 'warehouse_type' to be a str")
        pulumi.set(__self__, "warehouse_type", warehouse_type)

    @_builtins.property
    @pulumi.getter(name="autoStopMins")
    def auto_stop_mins(self) -> _builtins.int:
        """
        Time in minutes until an idle SQL warehouse terminates all clusters and stops.
        """
        return pulumi.get(self, "auto_stop_mins")

    @_builtins.property
    @pulumi.getter
    def channel(self) -> 'outputs.GetSqlWarehouseChannelResult':
        """
        block, consisting of following fields:
        """
        return pulumi.get(self, "channel")

    @_builtins.property
    @pulumi.getter(name="clusterSize")
    def cluster_size(self) -> _builtins.str:
        """
        The size of the clusters allocated to the warehouse: "2X-Small", "X-Small", "Small", "Medium", "Large", "X-Large", "2X-Large", "3X-Large", "4X-Large", "5X-Large".
        """
        return pulumi.get(self, "cluster_size")

    @_builtins.property
    @pulumi.getter(name="creatorName")
    def creator_name(self) -> _builtins.str:
        """
        The username of the user who created the endpoint.
        """
        return pulumi.get(self, "creator_name")

    @_builtins.property
    @pulumi.getter(name="dataSourceId")
    def data_source_id(self) -> _builtins.str:
        """
        (Deprecated, will be removed) ID of the data source for this warehouse. This is used to bind an Databricks SQL query to an warehouse.
        """
        return pulumi.get(self, "data_source_id")

    @_builtins.property
    @pulumi.getter(name="enablePhoton")
    def enable_photon(self) -> _builtins.bool:
        """
        Whether [Photon](https://databricks.com/product/delta-engine) is enabled.
        """
        return pulumi.get(self, "enable_photon")

    @_builtins.property
    @pulumi.getter(name="enableServerlessCompute")
    def enable_serverless_compute(self) -> _builtins.bool:
        """
        Whether this SQL warehouse is a serverless SQL warehouse.
        """
        return pulumi.get(self, "enable_serverless_compute")

    @_builtins.property
    @pulumi.getter
    def health(self) -> 'outputs.GetSqlWarehouseHealthResult':
        """
        Health status of the endpoint.
        """
        return pulumi.get(self, "health")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the SQL warehouse.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="instanceProfileArn")
    def instance_profile_arn(self) -> _builtins.str:
        return pulumi.get(self, "instance_profile_arn")

    @_builtins.property
    @pulumi.getter(name="jdbcUrl")
    def jdbc_url(self) -> _builtins.str:
        """
        JDBC connection string.
        """
        return pulumi.get(self, "jdbc_url")

    @_builtins.property
    @pulumi.getter(name="maxNumClusters")
    def max_num_clusters(self) -> _builtins.int:
        """
        Maximum number of clusters available when a SQL warehouse is running.
        """
        return pulumi.get(self, "max_num_clusters")

    @_builtins.property
    @pulumi.getter(name="minNumClusters")
    def min_num_clusters(self) -> _builtins.int:
        """
        Minimum number of clusters available when a SQL warehouse is running.
        """
        return pulumi.get(self, "min_num_clusters")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the Databricks SQL release channel. Possible values are: `CHANNEL_NAME_PREVIEW` and `CHANNEL_NAME_CURRENT`. Default is `CHANNEL_NAME_CURRENT`.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="numActiveSessions")
    def num_active_sessions(self) -> _builtins.int:
        """
        The current number of clusters used by the endpoint.
        """
        return pulumi.get(self, "num_active_sessions")

    @_builtins.property
    @pulumi.getter(name="numClusters")
    def num_clusters(self) -> _builtins.int:
        """
        The current number of clusters used by the endpoint.
        """
        return pulumi.get(self, "num_clusters")

    @_builtins.property
    @pulumi.getter(name="odbcParams")
    def odbc_params(self) -> 'outputs.GetSqlWarehouseOdbcParamsResult':
        """
        ODBC connection params: `odbc_params.hostname`, `odbc_params.path`, `odbc_params.protocol`, and `odbc_params.port`.
        """
        return pulumi.get(self, "odbc_params")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetSqlWarehouseProviderConfigResult']:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="spotInstancePolicy")
    def spot_instance_policy(self) -> _builtins.str:
        """
        The spot policy to use for allocating instances to clusters: `COST_OPTIMIZED` or `RELIABILITY_OPTIMIZED`.
        """
        return pulumi.get(self, "spot_instance_policy")

    @_builtins.property
    @pulumi.getter
    def state(self) -> _builtins.str:
        """
        The current state of the endpoint.
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> 'outputs.GetSqlWarehouseTagsResult':
        """
        tags used for SQL warehouse resources.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="warehouseType")
    def warehouse_type(self) -> _builtins.str:
        """
        SQL warehouse type. See [documentation](https://docs.databricks.com/sql/index.html#warehouse-types).
        """
        return pulumi.get(self, "warehouse_type")


class AwaitableGetSqlWarehouseResult(GetSqlWarehouseResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSqlWarehouseResult(
            auto_stop_mins=self.auto_stop_mins,
            channel=self.channel,
            cluster_size=self.cluster_size,
            creator_name=self.creator_name,
            data_source_id=self.data_source_id,
            enable_photon=self.enable_photon,
            enable_serverless_compute=self.enable_serverless_compute,
            health=self.health,
            id=self.id,
            instance_profile_arn=self.instance_profile_arn,
            jdbc_url=self.jdbc_url,
            max_num_clusters=self.max_num_clusters,
            min_num_clusters=self.min_num_clusters,
            name=self.name,
            num_active_sessions=self.num_active_sessions,
            num_clusters=self.num_clusters,
            odbc_params=self.odbc_params,
            provider_config=self.provider_config,
            spot_instance_policy=self.spot_instance_policy,
            state=self.state,
            tags=self.tags,
            warehouse_type=self.warehouse_type)


def get_sql_warehouse(auto_stop_mins: Optional[_builtins.int] = None,
                      channel: Optional[Union['GetSqlWarehouseChannelArgs', 'GetSqlWarehouseChannelArgsDict']] = None,
                      cluster_size: Optional[_builtins.str] = None,
                      creator_name: Optional[_builtins.str] = None,
                      data_source_id: Optional[_builtins.str] = None,
                      enable_photon: Optional[_builtins.bool] = None,
                      enable_serverless_compute: Optional[_builtins.bool] = None,
                      health: Optional[Union['GetSqlWarehouseHealthArgs', 'GetSqlWarehouseHealthArgsDict']] = None,
                      id: Optional[_builtins.str] = None,
                      instance_profile_arn: Optional[_builtins.str] = None,
                      jdbc_url: Optional[_builtins.str] = None,
                      max_num_clusters: Optional[_builtins.int] = None,
                      min_num_clusters: Optional[_builtins.int] = None,
                      name: Optional[_builtins.str] = None,
                      num_active_sessions: Optional[_builtins.int] = None,
                      num_clusters: Optional[_builtins.int] = None,
                      odbc_params: Optional[Union['GetSqlWarehouseOdbcParamsArgs', 'GetSqlWarehouseOdbcParamsArgsDict']] = None,
                      provider_config: Optional[Union['GetSqlWarehouseProviderConfigArgs', 'GetSqlWarehouseProviderConfigArgsDict']] = None,
                      spot_instance_policy: Optional[_builtins.str] = None,
                      state: Optional[_builtins.str] = None,
                      tags: Optional[Union['GetSqlWarehouseTagsArgs', 'GetSqlWarehouseTagsArgsDict']] = None,
                      warehouse_type: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSqlWarehouseResult:
    """
    Retrieves information about a get_sql_warehouse using its id. This could be retrieved programmatically using get_sql_warehouses data source.

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    * Retrieve attributes of each SQL warehouses in a workspace:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_sql_warehouses()
    this = {__key: databricks.get_sql_warehouse(id=__value) for __key, __value in all.ids}
    ```

    * Search for a specific SQL Warehouse by name:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_sql_warehouse(name="Starter Warehouse")
    ```

    ## Related resources

    The following resources are often used in the same context:

    * End to end workspace management guide.
    * InstanceProfile to manage AWS EC2 instance profiles that users can launch Cluster and access data, like databricks_mount.
    * SqlDashboard to manage Databricks SQL [Dashboards](https://docs.databricks.com/sql/user/dashboards/index.html).
    * SqlGlobalConfig to configure the security policy, databricks_instance_profile, and [data access properties](https://docs.databricks.com/sql/admin/data-access-configuration.html) for all get_sql_warehouse of workspace.
    * Grants to manage data access in Unity Catalog.


    :param _builtins.int auto_stop_mins: Time in minutes until an idle SQL warehouse terminates all clusters and stops.
    :param Union['GetSqlWarehouseChannelArgs', 'GetSqlWarehouseChannelArgsDict'] channel: block, consisting of following fields:
    :param _builtins.str cluster_size: The size of the clusters allocated to the warehouse: "2X-Small", "X-Small", "Small", "Medium", "Large", "X-Large", "2X-Large", "3X-Large", "4X-Large", "5X-Large".
    :param _builtins.str creator_name: The username of the user who created the endpoint.
    :param _builtins.str data_source_id: (Deprecated, will be removed) ID of the data source for this warehouse. This is used to bind an Databricks SQL query to an warehouse.
    :param _builtins.bool enable_photon: Whether [Photon](https://databricks.com/product/delta-engine) is enabled.
    :param _builtins.bool enable_serverless_compute: Whether this SQL warehouse is a serverless SQL warehouse.
    :param Union['GetSqlWarehouseHealthArgs', 'GetSqlWarehouseHealthArgsDict'] health: Health status of the endpoint.
    :param _builtins.str id: The ID of the SQL warehouse.
    :param _builtins.str jdbc_url: JDBC connection string.
    :param _builtins.int max_num_clusters: Maximum number of clusters available when a SQL warehouse is running.
    :param _builtins.int min_num_clusters: Minimum number of clusters available when a SQL warehouse is running.
    :param _builtins.str name: Name of the SQL warehouse to search (case-sensitive).
    :param _builtins.int num_active_sessions: The current number of clusters used by the endpoint.
    :param _builtins.int num_clusters: The current number of clusters used by the endpoint.
    :param Union['GetSqlWarehouseOdbcParamsArgs', 'GetSqlWarehouseOdbcParamsArgsDict'] odbc_params: ODBC connection params: `odbc_params.hostname`, `odbc_params.path`, `odbc_params.protocol`, and `odbc_params.port`.
    :param _builtins.str spot_instance_policy: The spot policy to use for allocating instances to clusters: `COST_OPTIMIZED` or `RELIABILITY_OPTIMIZED`.
    :param _builtins.str state: The current state of the endpoint.
    :param Union['GetSqlWarehouseTagsArgs', 'GetSqlWarehouseTagsArgsDict'] tags: tags used for SQL warehouse resources.
    :param _builtins.str warehouse_type: SQL warehouse type. See [documentation](https://docs.databricks.com/sql/index.html#warehouse-types).
    """
    __args__ = dict()
    __args__['autoStopMins'] = auto_stop_mins
    __args__['channel'] = channel
    __args__['clusterSize'] = cluster_size
    __args__['creatorName'] = creator_name
    __args__['dataSourceId'] = data_source_id
    __args__['enablePhoton'] = enable_photon
    __args__['enableServerlessCompute'] = enable_serverless_compute
    __args__['health'] = health
    __args__['id'] = id
    __args__['instanceProfileArn'] = instance_profile_arn
    __args__['jdbcUrl'] = jdbc_url
    __args__['maxNumClusters'] = max_num_clusters
    __args__['minNumClusters'] = min_num_clusters
    __args__['name'] = name
    __args__['numActiveSessions'] = num_active_sessions
    __args__['numClusters'] = num_clusters
    __args__['odbcParams'] = odbc_params
    __args__['providerConfig'] = provider_config
    __args__['spotInstancePolicy'] = spot_instance_policy
    __args__['state'] = state
    __args__['tags'] = tags
    __args__['warehouseType'] = warehouse_type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getSqlWarehouse:getSqlWarehouse', __args__, opts=opts, typ=GetSqlWarehouseResult).value

    return AwaitableGetSqlWarehouseResult(
        auto_stop_mins=pulumi.get(__ret__, 'auto_stop_mins'),
        channel=pulumi.get(__ret__, 'channel'),
        cluster_size=pulumi.get(__ret__, 'cluster_size'),
        creator_name=pulumi.get(__ret__, 'creator_name'),
        data_source_id=pulumi.get(__ret__, 'data_source_id'),
        enable_photon=pulumi.get(__ret__, 'enable_photon'),
        enable_serverless_compute=pulumi.get(__ret__, 'enable_serverless_compute'),
        health=pulumi.get(__ret__, 'health'),
        id=pulumi.get(__ret__, 'id'),
        instance_profile_arn=pulumi.get(__ret__, 'instance_profile_arn'),
        jdbc_url=pulumi.get(__ret__, 'jdbc_url'),
        max_num_clusters=pulumi.get(__ret__, 'max_num_clusters'),
        min_num_clusters=pulumi.get(__ret__, 'min_num_clusters'),
        name=pulumi.get(__ret__, 'name'),
        num_active_sessions=pulumi.get(__ret__, 'num_active_sessions'),
        num_clusters=pulumi.get(__ret__, 'num_clusters'),
        odbc_params=pulumi.get(__ret__, 'odbc_params'),
        provider_config=pulumi.get(__ret__, 'provider_config'),
        spot_instance_policy=pulumi.get(__ret__, 'spot_instance_policy'),
        state=pulumi.get(__ret__, 'state'),
        tags=pulumi.get(__ret__, 'tags'),
        warehouse_type=pulumi.get(__ret__, 'warehouse_type'))
def get_sql_warehouse_output(auto_stop_mins: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                             channel: Optional[pulumi.Input[Optional[Union['GetSqlWarehouseChannelArgs', 'GetSqlWarehouseChannelArgsDict']]]] = None,
                             cluster_size: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             creator_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             data_source_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             enable_photon: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                             enable_serverless_compute: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                             health: Optional[pulumi.Input[Optional[Union['GetSqlWarehouseHealthArgs', 'GetSqlWarehouseHealthArgsDict']]]] = None,
                             id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             instance_profile_arn: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             jdbc_url: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             max_num_clusters: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                             min_num_clusters: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                             name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             num_active_sessions: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                             num_clusters: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                             odbc_params: Optional[pulumi.Input[Optional[Union['GetSqlWarehouseOdbcParamsArgs', 'GetSqlWarehouseOdbcParamsArgsDict']]]] = None,
                             provider_config: Optional[pulumi.Input[Optional[Union['GetSqlWarehouseProviderConfigArgs', 'GetSqlWarehouseProviderConfigArgsDict']]]] = None,
                             spot_instance_policy: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             state: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             tags: Optional[pulumi.Input[Optional[Union['GetSqlWarehouseTagsArgs', 'GetSqlWarehouseTagsArgsDict']]]] = None,
                             warehouse_type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSqlWarehouseResult]:
    """
    Retrieves information about a get_sql_warehouse using its id. This could be retrieved programmatically using get_sql_warehouses data source.

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    * Retrieve attributes of each SQL warehouses in a workspace:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_sql_warehouses()
    this = {__key: databricks.get_sql_warehouse(id=__value) for __key, __value in all.ids}
    ```

    * Search for a specific SQL Warehouse by name:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_sql_warehouse(name="Starter Warehouse")
    ```

    ## Related resources

    The following resources are often used in the same context:

    * End to end workspace management guide.
    * InstanceProfile to manage AWS EC2 instance profiles that users can launch Cluster and access data, like databricks_mount.
    * SqlDashboard to manage Databricks SQL [Dashboards](https://docs.databricks.com/sql/user/dashboards/index.html).
    * SqlGlobalConfig to configure the security policy, databricks_instance_profile, and [data access properties](https://docs.databricks.com/sql/admin/data-access-configuration.html) for all get_sql_warehouse of workspace.
    * Grants to manage data access in Unity Catalog.


    :param _builtins.int auto_stop_mins: Time in minutes until an idle SQL warehouse terminates all clusters and stops.
    :param Union['GetSqlWarehouseChannelArgs', 'GetSqlWarehouseChannelArgsDict'] channel: block, consisting of following fields:
    :param _builtins.str cluster_size: The size of the clusters allocated to the warehouse: "2X-Small", "X-Small", "Small", "Medium", "Large", "X-Large", "2X-Large", "3X-Large", "4X-Large", "5X-Large".
    :param _builtins.str creator_name: The username of the user who created the endpoint.
    :param _builtins.str data_source_id: (Deprecated, will be removed) ID of the data source for this warehouse. This is used to bind an Databricks SQL query to an warehouse.
    :param _builtins.bool enable_photon: Whether [Photon](https://databricks.com/product/delta-engine) is enabled.
    :param _builtins.bool enable_serverless_compute: Whether this SQL warehouse is a serverless SQL warehouse.
    :param Union['GetSqlWarehouseHealthArgs', 'GetSqlWarehouseHealthArgsDict'] health: Health status of the endpoint.
    :param _builtins.str id: The ID of the SQL warehouse.
    :param _builtins.str jdbc_url: JDBC connection string.
    :param _builtins.int max_num_clusters: Maximum number of clusters available when a SQL warehouse is running.
    :param _builtins.int min_num_clusters: Minimum number of clusters available when a SQL warehouse is running.
    :param _builtins.str name: Name of the SQL warehouse to search (case-sensitive).
    :param _builtins.int num_active_sessions: The current number of clusters used by the endpoint.
    :param _builtins.int num_clusters: The current number of clusters used by the endpoint.
    :param Union['GetSqlWarehouseOdbcParamsArgs', 'GetSqlWarehouseOdbcParamsArgsDict'] odbc_params: ODBC connection params: `odbc_params.hostname`, `odbc_params.path`, `odbc_params.protocol`, and `odbc_params.port`.
    :param _builtins.str spot_instance_policy: The spot policy to use for allocating instances to clusters: `COST_OPTIMIZED` or `RELIABILITY_OPTIMIZED`.
    :param _builtins.str state: The current state of the endpoint.
    :param Union['GetSqlWarehouseTagsArgs', 'GetSqlWarehouseTagsArgsDict'] tags: tags used for SQL warehouse resources.
    :param _builtins.str warehouse_type: SQL warehouse type. See [documentation](https://docs.databricks.com/sql/index.html#warehouse-types).
    """
    __args__ = dict()
    __args__['autoStopMins'] = auto_stop_mins
    __args__['channel'] = channel
    __args__['clusterSize'] = cluster_size
    __args__['creatorName'] = creator_name
    __args__['dataSourceId'] = data_source_id
    __args__['enablePhoton'] = enable_photon
    __args__['enableServerlessCompute'] = enable_serverless_compute
    __args__['health'] = health
    __args__['id'] = id
    __args__['instanceProfileArn'] = instance_profile_arn
    __args__['jdbcUrl'] = jdbc_url
    __args__['maxNumClusters'] = max_num_clusters
    __args__['minNumClusters'] = min_num_clusters
    __args__['name'] = name
    __args__['numActiveSessions'] = num_active_sessions
    __args__['numClusters'] = num_clusters
    __args__['odbcParams'] = odbc_params
    __args__['providerConfig'] = provider_config
    __args__['spotInstancePolicy'] = spot_instance_policy
    __args__['state'] = state
    __args__['tags'] = tags
    __args__['warehouseType'] = warehouse_type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getSqlWarehouse:getSqlWarehouse', __args__, opts=opts, typ=GetSqlWarehouseResult)
    return __ret__.apply(lambda __response__: GetSqlWarehouseResult(
        auto_stop_mins=pulumi.get(__response__, 'auto_stop_mins'),
        channel=pulumi.get(__response__, 'channel'),
        cluster_size=pulumi.get(__response__, 'cluster_size'),
        creator_name=pulumi.get(__response__, 'creator_name'),
        data_source_id=pulumi.get(__response__, 'data_source_id'),
        enable_photon=pulumi.get(__response__, 'enable_photon'),
        enable_serverless_compute=pulumi.get(__response__, 'enable_serverless_compute'),
        health=pulumi.get(__response__, 'health'),
        id=pulumi.get(__response__, 'id'),
        instance_profile_arn=pulumi.get(__response__, 'instance_profile_arn'),
        jdbc_url=pulumi.get(__response__, 'jdbc_url'),
        max_num_clusters=pulumi.get(__response__, 'max_num_clusters'),
        min_num_clusters=pulumi.get(__response__, 'min_num_clusters'),
        name=pulumi.get(__response__, 'name'),
        num_active_sessions=pulumi.get(__response__, 'num_active_sessions'),
        num_clusters=pulumi.get(__response__, 'num_clusters'),
        odbc_params=pulumi.get(__response__, 'odbc_params'),
        provider_config=pulumi.get(__response__, 'provider_config'),
        spot_instance_policy=pulumi.get(__response__, 'spot_instance_policy'),
        state=pulumi.get(__response__, 'state'),
        tags=pulumi.get(__response__, 'tags'),
        warehouse_type=pulumi.get(__response__, 'warehouse_type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['MwsCredentialsArgs', 'MwsCredentials']

@pulumi.input_type
class MwsCredentialsArgs:
    def __init__(__self__, *,
                 credentials_name: pulumi.Input[_builtins.str],
                 role_arn: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 creation_time: Optional[pulumi.Input[_builtins.int]] = None,
                 credentials_id: Optional[pulumi.Input[_builtins.str]] = None,
                 external_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a MwsCredentials resource.
        :param pulumi.Input[_builtins.str] credentials_name: name of credentials to register
        :param pulumi.Input[_builtins.str] role_arn: ARN of cross-account role
        :param pulumi.Input[_builtins.str] account_id: **(Deprecated)** Maintained for backwards compatibility and will be removed in a later version. It should now be specified under a provider instance where `host = "https://accounts.cloud.databricks.com"`
        :param pulumi.Input[_builtins.int] creation_time: (Integer) time of credentials registration
        :param pulumi.Input[_builtins.str] credentials_id: (String) identifier of credentials
        """
        pulumi.set(__self__, "credentials_name", credentials_name)
        pulumi.set(__self__, "role_arn", role_arn)
        if account_id is not None:
            warnings.warn("""`account_id` should be set as part of the Databricks Config, not in the resource.""", DeprecationWarning)
            pulumi.log.warn("""account_id is deprecated: `account_id` should be set as part of the Databricks Config, not in the resource.""")
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if creation_time is not None:
            pulumi.set(__self__, "creation_time", creation_time)
        if credentials_id is not None:
            pulumi.set(__self__, "credentials_id", credentials_id)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)

    @_builtins.property
    @pulumi.getter(name="credentialsName")
    def credentials_name(self) -> pulumi.Input[_builtins.str]:
        """
        name of credentials to register
        """
        return pulumi.get(self, "credentials_name")

    @credentials_name.setter
    def credentials_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "credentials_name", value)

    @_builtins.property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> pulumi.Input[_builtins.str]:
        """
        ARN of cross-account role
        """
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "role_arn", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""`account_id` should be set as part of the Databricks Config, not in the resource.""")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        **(Deprecated)** Maintained for backwards compatibility and will be removed in a later version. It should now be specified under a provider instance where `host = "https://accounts.cloud.databricks.com"`
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (Integer) time of credentials registration
        """
        return pulumi.get(self, "creation_time")

    @creation_time.setter
    def creation_time(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "creation_time", value)

    @_builtins.property
    @pulumi.getter(name="credentialsId")
    def credentials_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (String) identifier of credentials
        """
        return pulumi.get(self, "credentials_id")

    @credentials_id.setter
    def credentials_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "credentials_id", value)

    @_builtins.property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_id", value)


@pulumi.input_type
class _MwsCredentialsState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 creation_time: Optional[pulumi.Input[_builtins.int]] = None,
                 credentials_id: Optional[pulumi.Input[_builtins.str]] = None,
                 credentials_name: Optional[pulumi.Input[_builtins.str]] = None,
                 external_id: Optional[pulumi.Input[_builtins.str]] = None,
                 role_arn: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering MwsCredentials resources.
        :param pulumi.Input[_builtins.str] account_id: **(Deprecated)** Maintained for backwards compatibility and will be removed in a later version. It should now be specified under a provider instance where `host = "https://accounts.cloud.databricks.com"`
        :param pulumi.Input[_builtins.int] creation_time: (Integer) time of credentials registration
        :param pulumi.Input[_builtins.str] credentials_id: (String) identifier of credentials
        :param pulumi.Input[_builtins.str] credentials_name: name of credentials to register
        :param pulumi.Input[_builtins.str] role_arn: ARN of cross-account role
        """
        if account_id is not None:
            warnings.warn("""`account_id` should be set as part of the Databricks Config, not in the resource.""", DeprecationWarning)
            pulumi.log.warn("""account_id is deprecated: `account_id` should be set as part of the Databricks Config, not in the resource.""")
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if creation_time is not None:
            pulumi.set(__self__, "creation_time", creation_time)
        if credentials_id is not None:
            pulumi.set(__self__, "credentials_id", credentials_id)
        if credentials_name is not None:
            pulumi.set(__self__, "credentials_name", credentials_name)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if role_arn is not None:
            pulumi.set(__self__, "role_arn", role_arn)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""`account_id` should be set as part of the Databricks Config, not in the resource.""")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        **(Deprecated)** Maintained for backwards compatibility and will be removed in a later version. It should now be specified under a provider instance where `host = "https://accounts.cloud.databricks.com"`
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (Integer) time of credentials registration
        """
        return pulumi.get(self, "creation_time")

    @creation_time.setter
    def creation_time(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "creation_time", value)

    @_builtins.property
    @pulumi.getter(name="credentialsId")
    def credentials_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (String) identifier of credentials
        """
        return pulumi.get(self, "credentials_id")

    @credentials_id.setter
    def credentials_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "credentials_id", value)

    @_builtins.property
    @pulumi.getter(name="credentialsName")
    def credentials_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        name of credentials to register
        """
        return pulumi.get(self, "credentials_name")

    @credentials_name.setter
    def credentials_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "credentials_name", value)

    @_builtins.property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_id", value)

    @_builtins.property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ARN of cross-account role
        """
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "role_arn", value)


@pulumi.type_token("databricks:index/mwsCredentials:MwsCredentials")
class MwsCredentials(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 creation_time: Optional[pulumi.Input[_builtins.int]] = None,
                 credentials_id: Optional[pulumi.Input[_builtins.str]] = None,
                 credentials_name: Optional[pulumi.Input[_builtins.str]] = None,
                 external_id: Optional[pulumi.Input[_builtins.str]] = None,
                 role_arn: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource to configure the cross-account role for creation of new workspaces within AWS.

        > This resource can only be used with an account-level provider!

        Please follow this complete runnable example with new VPC and new workspace setup. Please pay special attention to the fact that there you have two different instances of a databricks provider - one for deploying workspaces (with `host="https://accounts.cloud.databricks.com/"`) and another for the workspace you've created with `MwsWorkspaces` resource. If you want both creation of workspaces & clusters within workspace within the same terraform module (essentially same directory), you should use the provider aliasing feature of Pulumi. We strongly recommend having one terraform module for creation of workspace + PAT token and the rest in different modules.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws
        import pulumi_databricks as databricks

        config = pulumi.Config()
        # Account Id that could be found in the top right corner of https://accounts.cloud.databricks.com/
        databricks_account_id = config.require_object("databricksAccountId")
        # Names of created resources will be prefixed with this value
        prefix = config.require_object("prefix")
        this = databricks.get_aws_assume_role_policy(external_id=databricks_account_id)
        cross_account_role = aws.index.IamRole("cross_account_role",
            name=f{prefix}-crossaccount,
            assume_role_policy=this.json,
            tags=tags)
        this_get_aws_cross_account_policy = databricks.get_aws_cross_account_policy()
        this_iam_role_policy = aws.index.IamRolePolicy("this",
            name=f{prefix}-policy,
            role=cross_account_role.id,
            policy=this_get_aws_cross_account_policy.json)
        this_mws_credentials = databricks.MwsCredentials("this",
            credentials_name=f"{prefix}-creds",
            role_arn=cross_account_role["arn"])
        ```

        ## Related Resources

        The following resources are used in the same context:

        * Provisioning Databricks on AWS guide.
        * MwsCustomerManagedKeys to configure KMS keys for new workspaces within AWS.
        * MwsLogDelivery to configure delivery of [billable usage logs](https://docs.databricks.com/administration-guide/account-settings/billable-usage-delivery.html) and [audit logs](https://docs.databricks.com/administration-guide/account-settings/audit-logs.html).
        * MwsNetworks to [configure VPC](https://docs.databricks.com/administration-guide/cloud-configurations/aws/customer-managed-vpc.html) & subnets for new workspaces within AWS.
        * MwsStorageConfigurations to configure root bucket new workspaces within AWS.
        * MwsWorkspaces to set up [AWS and GCP workspaces](https://docs.databricks.com/getting-started/overview.html#e2-architecture-1).

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: **(Deprecated)** Maintained for backwards compatibility and will be removed in a later version. It should now be specified under a provider instance where `host = "https://accounts.cloud.databricks.com"`
        :param pulumi.Input[_builtins.int] creation_time: (Integer) time of credentials registration
        :param pulumi.Input[_builtins.str] credentials_id: (String) identifier of credentials
        :param pulumi.Input[_builtins.str] credentials_name: name of credentials to register
        :param pulumi.Input[_builtins.str] role_arn: ARN of cross-account role
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MwsCredentialsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource to configure the cross-account role for creation of new workspaces within AWS.

        > This resource can only be used with an account-level provider!

        Please follow this complete runnable example with new VPC and new workspace setup. Please pay special attention to the fact that there you have two different instances of a databricks provider - one for deploying workspaces (with `host="https://accounts.cloud.databricks.com/"`) and another for the workspace you've created with `MwsWorkspaces` resource. If you want both creation of workspaces & clusters within workspace within the same terraform module (essentially same directory), you should use the provider aliasing feature of Pulumi. We strongly recommend having one terraform module for creation of workspace + PAT token and the rest in different modules.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws
        import pulumi_databricks as databricks

        config = pulumi.Config()
        # Account Id that could be found in the top right corner of https://accounts.cloud.databricks.com/
        databricks_account_id = config.require_object("databricksAccountId")
        # Names of created resources will be prefixed with this value
        prefix = config.require_object("prefix")
        this = databricks.get_aws_assume_role_policy(external_id=databricks_account_id)
        cross_account_role = aws.index.IamRole("cross_account_role",
            name=f{prefix}-crossaccount,
            assume_role_policy=this.json,
            tags=tags)
        this_get_aws_cross_account_policy = databricks.get_aws_cross_account_policy()
        this_iam_role_policy = aws.index.IamRolePolicy("this",
            name=f{prefix}-policy,
            role=cross_account_role.id,
            policy=this_get_aws_cross_account_policy.json)
        this_mws_credentials = databricks.MwsCredentials("this",
            credentials_name=f"{prefix}-creds",
            role_arn=cross_account_role["arn"])
        ```

        ## Related Resources

        The following resources are used in the same context:

        * Provisioning Databricks on AWS guide.
        * MwsCustomerManagedKeys to configure KMS keys for new workspaces within AWS.
        * MwsLogDelivery to configure delivery of [billable usage logs](https://docs.databricks.com/administration-guide/account-settings/billable-usage-delivery.html) and [audit logs](https://docs.databricks.com/administration-guide/account-settings/audit-logs.html).
        * MwsNetworks to [configure VPC](https://docs.databricks.com/administration-guide/cloud-configurations/aws/customer-managed-vpc.html) & subnets for new workspaces within AWS.
        * MwsStorageConfigurations to configure root bucket new workspaces within AWS.
        * MwsWorkspaces to set up [AWS and GCP workspaces](https://docs.databricks.com/getting-started/overview.html#e2-architecture-1).

        :param str resource_name: The name of the resource.
        :param MwsCredentialsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MwsCredentialsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 creation_time: Optional[pulumi.Input[_builtins.int]] = None,
                 credentials_id: Optional[pulumi.Input[_builtins.str]] = None,
                 credentials_name: Optional[pulumi.Input[_builtins.str]] = None,
                 external_id: Optional[pulumi.Input[_builtins.str]] = None,
                 role_arn: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MwsCredentialsArgs.__new__(MwsCredentialsArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["creation_time"] = creation_time
            __props__.__dict__["credentials_id"] = credentials_id
            if credentials_name is None and not opts.urn:
                raise TypeError("Missing required property 'credentials_name'")
            __props__.__dict__["credentials_name"] = credentials_name
            __props__.__dict__["external_id"] = external_id
            if role_arn is None and not opts.urn:
                raise TypeError("Missing required property 'role_arn'")
            __props__.__dict__["role_arn"] = role_arn
        super(MwsCredentials, __self__).__init__(
            'databricks:index/mwsCredentials:MwsCredentials',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            creation_time: Optional[pulumi.Input[_builtins.int]] = None,
            credentials_id: Optional[pulumi.Input[_builtins.str]] = None,
            credentials_name: Optional[pulumi.Input[_builtins.str]] = None,
            external_id: Optional[pulumi.Input[_builtins.str]] = None,
            role_arn: Optional[pulumi.Input[_builtins.str]] = None) -> 'MwsCredentials':
        """
        Get an existing MwsCredentials resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: **(Deprecated)** Maintained for backwards compatibility and will be removed in a later version. It should now be specified under a provider instance where `host = "https://accounts.cloud.databricks.com"`
        :param pulumi.Input[_builtins.int] creation_time: (Integer) time of credentials registration
        :param pulumi.Input[_builtins.str] credentials_id: (String) identifier of credentials
        :param pulumi.Input[_builtins.str] credentials_name: name of credentials to register
        :param pulumi.Input[_builtins.str] role_arn: ARN of cross-account role
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MwsCredentialsState.__new__(_MwsCredentialsState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["creation_time"] = creation_time
        __props__.__dict__["credentials_id"] = credentials_id
        __props__.__dict__["credentials_name"] = credentials_name
        __props__.__dict__["external_id"] = external_id
        __props__.__dict__["role_arn"] = role_arn
        return MwsCredentials(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""`account_id` should be set as part of the Databricks Config, not in the resource.""")
    def account_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        **(Deprecated)** Maintained for backwards compatibility and will be removed in a later version. It should now be specified under a provider instance where `host = "https://accounts.cloud.databricks.com"`
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> pulumi.Output[_builtins.int]:
        """
        (Integer) time of credentials registration
        """
        return pulumi.get(self, "creation_time")

    @_builtins.property
    @pulumi.getter(name="credentialsId")
    def credentials_id(self) -> pulumi.Output[_builtins.str]:
        """
        (String) identifier of credentials
        """
        return pulumi.get(self, "credentials_id")

    @_builtins.property
    @pulumi.getter(name="credentialsName")
    def credentials_name(self) -> pulumi.Output[_builtins.str]:
        """
        name of credentials to register
        """
        return pulumi.get(self, "credentials_name")

    @_builtins.property
    @pulumi.getter(name="externalId")
    def external_id(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "external_id")

    @_builtins.property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> pulumi.Output[_builtins.str]:
        """
        ARN of cross-account role
        """
        return pulumi.get(self, "role_arn")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetMwsNetworkConnectivityConfigResult',
    'AwaitableGetMwsNetworkConnectivityConfigResult',
    'get_mws_network_connectivity_config',
    'get_mws_network_connectivity_config_output',
]

@pulumi.output_type
class GetMwsNetworkConnectivityConfigResult:
    """
    A collection of values returned by getMwsNetworkConnectivityConfig.
    """
    def __init__(__self__, account_id=None, creation_time=None, egress_config=None, id=None, name=None, network_connectivity_config_id=None, region=None, updated_time=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if creation_time and not isinstance(creation_time, int):
            raise TypeError("Expected argument 'creation_time' to be a int")
        pulumi.set(__self__, "creation_time", creation_time)
        if egress_config and not isinstance(egress_config, dict):
            raise TypeError("Expected argument 'egress_config' to be a dict")
        pulumi.set(__self__, "egress_config", egress_config)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if network_connectivity_config_id and not isinstance(network_connectivity_config_id, str):
            raise TypeError("Expected argument 'network_connectivity_config_id' to be a str")
        pulumi.set(__self__, "network_connectivity_config_id", network_connectivity_config_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if updated_time and not isinstance(updated_time, int):
            raise TypeError("Expected argument 'updated_time' to be a int")
        pulumi.set(__self__, "updated_time", updated_time)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> _builtins.str:
        """
        The Databricks account ID associated with this network configuration.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> _builtins.int:
        """
        Time in epoch milliseconds when this object was created.
        """
        return pulumi.get(self, "creation_time")

    @_builtins.property
    @pulumi.getter(name="egressConfig")
    def egress_config(self) -> 'outputs.GetMwsNetworkConnectivityConfigEgressConfigResult':
        """
        Array of egress configuration objects.
        """
        return pulumi.get(self, "egress_config")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the network connectivity configuration.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="networkConnectivityConfigId")
    def network_connectivity_config_id(self) -> _builtins.str:
        """
        The Databricks network connectivity configuration ID.
        """
        return pulumi.get(self, "network_connectivity_config_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The region of the network connectivity configuration.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> _builtins.int:
        """
        Time in epoch milliseconds when the network was updated.
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetMwsNetworkConnectivityConfigResult(GetMwsNetworkConnectivityConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMwsNetworkConnectivityConfigResult(
            account_id=self.account_id,
            creation_time=self.creation_time,
            egress_config=self.egress_config,
            id=self.id,
            name=self.name,
            network_connectivity_config_id=self.network_connectivity_config_id,
            region=self.region,
            updated_time=self.updated_time)


def get_mws_network_connectivity_config(account_id: Optional[_builtins.str] = None,
                                        creation_time: Optional[_builtins.int] = None,
                                        egress_config: Optional[Union['GetMwsNetworkConnectivityConfigEgressConfigArgs', 'GetMwsNetworkConnectivityConfigEgressConfigArgsDict']] = None,
                                        name: Optional[_builtins.str] = None,
                                        network_connectivity_config_id: Optional[_builtins.str] = None,
                                        region: Optional[_builtins.str] = None,
                                        updated_time: Optional[_builtins.int] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMwsNetworkConnectivityConfigResult:
    """
    Retrieves information about MwsNetworkConnectivityConfig in Databricks Account.

    > This data source can only be used with an account-level provider!

    ## Example Usage

    Fetching information about a network connectivity configuration in Databricks Account

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_mws_network_connectivity_config(name="ncc")
    pulumi.export("config", this)
    ```

    ## Related Resources

    The following resources are used in the same context:

    * get_mws_network_connectivity_configs to get names of all network connectivity configurations.
    * MwsNetworkConnectivityConfig to manage network connectivity configuration.


    :param _builtins.str account_id: The Databricks account ID associated with this network configuration.
    :param _builtins.int creation_time: Time in epoch milliseconds when this object was created.
    :param Union['GetMwsNetworkConnectivityConfigEgressConfigArgs', 'GetMwsNetworkConnectivityConfigEgressConfigArgsDict'] egress_config: Array of egress configuration objects.
    :param _builtins.str name: Name of the network connectivity configuration.
    :param _builtins.str network_connectivity_config_id: The Databricks network connectivity configuration ID.
    :param _builtins.str region: The region of the network connectivity configuration.
    :param _builtins.int updated_time: Time in epoch milliseconds when the network was updated.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['creationTime'] = creation_time
    __args__['egressConfig'] = egress_config
    __args__['name'] = name
    __args__['networkConnectivityConfigId'] = network_connectivity_config_id
    __args__['region'] = region
    __args__['updatedTime'] = updated_time
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getMwsNetworkConnectivityConfig:getMwsNetworkConnectivityConfig', __args__, opts=opts, typ=GetMwsNetworkConnectivityConfigResult).value

    return AwaitableGetMwsNetworkConnectivityConfigResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        creation_time=pulumi.get(__ret__, 'creation_time'),
        egress_config=pulumi.get(__ret__, 'egress_config'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        network_connectivity_config_id=pulumi.get(__ret__, 'network_connectivity_config_id'),
        region=pulumi.get(__ret__, 'region'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_mws_network_connectivity_config_output(account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                               creation_time: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                               egress_config: Optional[pulumi.Input[Optional[Union['GetMwsNetworkConnectivityConfigEgressConfigArgs', 'GetMwsNetworkConnectivityConfigEgressConfigArgsDict']]]] = None,
                                               name: Optional[pulumi.Input[_builtins.str]] = None,
                                               network_connectivity_config_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                               region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                               updated_time: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetMwsNetworkConnectivityConfigResult]:
    """
    Retrieves information about MwsNetworkConnectivityConfig in Databricks Account.

    > This data source can only be used with an account-level provider!

    ## Example Usage

    Fetching information about a network connectivity configuration in Databricks Account

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_mws_network_connectivity_config(name="ncc")
    pulumi.export("config", this)
    ```

    ## Related Resources

    The following resources are used in the same context:

    * get_mws_network_connectivity_configs to get names of all network connectivity configurations.
    * MwsNetworkConnectivityConfig to manage network connectivity configuration.


    :param _builtins.str account_id: The Databricks account ID associated with this network configuration.
    :param _builtins.int creation_time: Time in epoch milliseconds when this object was created.
    :param Union['GetMwsNetworkConnectivityConfigEgressConfigArgs', 'GetMwsNetworkConnectivityConfigEgressConfigArgsDict'] egress_config: Array of egress configuration objects.
    :param _builtins.str name: Name of the network connectivity configuration.
    :param _builtins.str network_connectivity_config_id: The Databricks network connectivity configuration ID.
    :param _builtins.str region: The region of the network connectivity configuration.
    :param _builtins.int updated_time: Time in epoch milliseconds when the network was updated.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['creationTime'] = creation_time
    __args__['egressConfig'] = egress_config
    __args__['name'] = name
    __args__['networkConnectivityConfigId'] = network_connectivity_config_id
    __args__['region'] = region
    __args__['updatedTime'] = updated_time
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getMwsNetworkConnectivityConfig:getMwsNetworkConnectivityConfig', __args__, opts=opts, typ=GetMwsNetworkConnectivityConfigResult)
    return __ret__.apply(lambda __response__: GetMwsNetworkConnectivityConfigResult(
        account_id=pulumi.get(__response__, 'account_id'),
        creation_time=pulumi.get(__response__, 'creation_time'),
        egress_config=pulumi.get(__response__, 'egress_config'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        network_connectivity_config_id=pulumi.get(__response__, 'network_connectivity_config_id'),
        region=pulumi.get(__response__, 'region'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAppSpaceResult',
    'AwaitableGetAppSpaceResult',
    'get_app_space',
    'get_app_space_output',
]

@pulumi.output_type
class GetAppSpaceResult:
    """
    A collection of values returned by getAppSpace.
    """
    def __init__(__self__, create_time=None, creator=None, description=None, effective_usage_policy_id=None, effective_user_api_scopes=None, id=None, name=None, provider_config=None, resources=None, service_principal_client_id=None, service_principal_id=None, service_principal_name=None, status=None, update_time=None, updater=None, usage_policy_id=None, user_api_scopes=None):
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if creator and not isinstance(creator, str):
            raise TypeError("Expected argument 'creator' to be a str")
        pulumi.set(__self__, "creator", creator)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if effective_usage_policy_id and not isinstance(effective_usage_policy_id, str):
            raise TypeError("Expected argument 'effective_usage_policy_id' to be a str")
        pulumi.set(__self__, "effective_usage_policy_id", effective_usage_policy_id)
        if effective_user_api_scopes and not isinstance(effective_user_api_scopes, list):
            raise TypeError("Expected argument 'effective_user_api_scopes' to be a list")
        pulumi.set(__self__, "effective_user_api_scopes", effective_user_api_scopes)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)
        if resources and not isinstance(resources, list):
            raise TypeError("Expected argument 'resources' to be a list")
        pulumi.set(__self__, "resources", resources)
        if service_principal_client_id and not isinstance(service_principal_client_id, str):
            raise TypeError("Expected argument 'service_principal_client_id' to be a str")
        pulumi.set(__self__, "service_principal_client_id", service_principal_client_id)
        if service_principal_id and not isinstance(service_principal_id, int):
            raise TypeError("Expected argument 'service_principal_id' to be a int")
        pulumi.set(__self__, "service_principal_id", service_principal_id)
        if service_principal_name and not isinstance(service_principal_name, str):
            raise TypeError("Expected argument 'service_principal_name' to be a str")
        pulumi.set(__self__, "service_principal_name", service_principal_name)
        if status and not isinstance(status, dict):
            raise TypeError("Expected argument 'status' to be a dict")
        pulumi.set(__self__, "status", status)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)
        if updater and not isinstance(updater, str):
            raise TypeError("Expected argument 'updater' to be a str")
        pulumi.set(__self__, "updater", updater)
        if usage_policy_id and not isinstance(usage_policy_id, str):
            raise TypeError("Expected argument 'usage_policy_id' to be a str")
        pulumi.set(__self__, "usage_policy_id", usage_policy_id)
        if user_api_scopes and not isinstance(user_api_scopes, list):
            raise TypeError("Expected argument 'user_api_scopes' to be a list")
        pulumi.set(__self__, "user_api_scopes", user_api_scopes)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> _builtins.str:
        """
        (string) - The creation time of the app space. Formatted timestamp in ISO 6801
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def creator(self) -> _builtins.str:
        """
        (string) - The email of the user that created the app space
        """
        return pulumi.get(self, "creator")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        (string) - Description of the App Resource
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="effectiveUsagePolicyId")
    def effective_usage_policy_id(self) -> _builtins.str:
        """
        (string) - The effective usage policy ID used by apps in the space
        """
        return pulumi.get(self, "effective_usage_policy_id")

    @_builtins.property
    @pulumi.getter(name="effectiveUserApiScopes")
    def effective_user_api_scopes(self) -> Sequence[_builtins.str]:
        """
        (list of string) - The effective api scopes granted to the user access token
        """
        return pulumi.get(self, "effective_user_api_scopes")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        (string) - Id of the SQL warehouse to grant permission on
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (string) - Name of the serving endpoint to grant permission on
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetAppSpaceProviderConfigResult']:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter
    def resources(self) -> Sequence['outputs.GetAppSpaceResourceResult']:
        """
        (list of AppResource) - Resources for the app space. Resources configured at the space level are available to all apps in the space
        """
        return pulumi.get(self, "resources")

    @_builtins.property
    @pulumi.getter(name="servicePrincipalClientId")
    def service_principal_client_id(self) -> _builtins.str:
        """
        (string) - The service principal client ID for the app space
        """
        return pulumi.get(self, "service_principal_client_id")

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> _builtins.int:
        """
        (integer) - The service principal ID for the app space
        """
        return pulumi.get(self, "service_principal_id")

    @_builtins.property
    @pulumi.getter(name="servicePrincipalName")
    def service_principal_name(self) -> _builtins.str:
        """
        (string) - The service principal name for the app space
        """
        return pulumi.get(self, "service_principal_name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> 'outputs.GetAppSpaceStatusResult':
        """
        (SpaceStatus) - The status of the app space
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> _builtins.str:
        """
        (string) - The update time of the app space. Formatted timestamp in ISO 6801
        """
        return pulumi.get(self, "update_time")

    @_builtins.property
    @pulumi.getter
    def updater(self) -> _builtins.str:
        """
        (string) - The email of the user that last updated the app space
        """
        return pulumi.get(self, "updater")

    @_builtins.property
    @pulumi.getter(name="usagePolicyId")
    def usage_policy_id(self) -> _builtins.str:
        """
        (string) - The usage policy ID for managing cost at the space level
        """
        return pulumi.get(self, "usage_policy_id")

    @_builtins.property
    @pulumi.getter(name="userApiScopes")
    def user_api_scopes(self) -> Sequence[_builtins.str]:
        """
        (list of string) - OAuth scopes for apps in the space
        """
        return pulumi.get(self, "user_api_scopes")


class AwaitableGetAppSpaceResult(GetAppSpaceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAppSpaceResult(
            create_time=self.create_time,
            creator=self.creator,
            description=self.description,
            effective_usage_policy_id=self.effective_usage_policy_id,
            effective_user_api_scopes=self.effective_user_api_scopes,
            id=self.id,
            name=self.name,
            provider_config=self.provider_config,
            resources=self.resources,
            service_principal_client_id=self.service_principal_client_id,
            service_principal_id=self.service_principal_id,
            service_principal_name=self.service_principal_name,
            status=self.status,
            update_time=self.update_time,
            updater=self.updater,
            usage_policy_id=self.usage_policy_id,
            user_api_scopes=self.user_api_scopes)


def get_app_space(name: Optional[_builtins.str] = None,
                  provider_config: Optional[Union['GetAppSpaceProviderConfigArgs', 'GetAppSpaceProviderConfigArgsDict']] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAppSpaceResult:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str name: The name of the app space. The name must contain only lowercase alphanumeric characters and hyphens.
           It must be unique within the workspace
    :param Union['GetAppSpaceProviderConfigArgs', 'GetAppSpaceProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getAppSpace:getAppSpace', __args__, opts=opts, typ=GetAppSpaceResult).value

    return AwaitableGetAppSpaceResult(
        create_time=pulumi.get(__ret__, 'create_time'),
        creator=pulumi.get(__ret__, 'creator'),
        description=pulumi.get(__ret__, 'description'),
        effective_usage_policy_id=pulumi.get(__ret__, 'effective_usage_policy_id'),
        effective_user_api_scopes=pulumi.get(__ret__, 'effective_user_api_scopes'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        provider_config=pulumi.get(__ret__, 'provider_config'),
        resources=pulumi.get(__ret__, 'resources'),
        service_principal_client_id=pulumi.get(__ret__, 'service_principal_client_id'),
        service_principal_id=pulumi.get(__ret__, 'service_principal_id'),
        service_principal_name=pulumi.get(__ret__, 'service_principal_name'),
        status=pulumi.get(__ret__, 'status'),
        update_time=pulumi.get(__ret__, 'update_time'),
        updater=pulumi.get(__ret__, 'updater'),
        usage_policy_id=pulumi.get(__ret__, 'usage_policy_id'),
        user_api_scopes=pulumi.get(__ret__, 'user_api_scopes'))
def get_app_space_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                         provider_config: Optional[pulumi.Input[Optional[Union['GetAppSpaceProviderConfigArgs', 'GetAppSpaceProviderConfigArgsDict']]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAppSpaceResult]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str name: The name of the app space. The name must contain only lowercase alphanumeric characters and hyphens.
           It must be unique within the workspace
    :param Union['GetAppSpaceProviderConfigArgs', 'GetAppSpaceProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getAppSpace:getAppSpace', __args__, opts=opts, typ=GetAppSpaceResult)
    return __ret__.apply(lambda __response__: GetAppSpaceResult(
        create_time=pulumi.get(__response__, 'create_time'),
        creator=pulumi.get(__response__, 'creator'),
        description=pulumi.get(__response__, 'description'),
        effective_usage_policy_id=pulumi.get(__response__, 'effective_usage_policy_id'),
        effective_user_api_scopes=pulumi.get(__response__, 'effective_user_api_scopes'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        provider_config=pulumi.get(__response__, 'provider_config'),
        resources=pulumi.get(__response__, 'resources'),
        service_principal_client_id=pulumi.get(__response__, 'service_principal_client_id'),
        service_principal_id=pulumi.get(__response__, 'service_principal_id'),
        service_principal_name=pulumi.get(__response__, 'service_principal_name'),
        status=pulumi.get(__response__, 'status'),
        update_time=pulumi.get(__response__, 'update_time'),
        updater=pulumi.get(__response__, 'updater'),
        usage_policy_id=pulumi.get(__response__, 'usage_policy_id'),
        user_api_scopes=pulumi.get(__response__, 'user_api_scopes')))
